import reflex as rx

class TiAdjustBrightness(rx.Component):
    library = "react-icons/ti"
    tag = "TiAdjustBrightness"


class TiAdjustContrast(rx.Component):
    library = "react-icons/ti"
    tag = "TiAdjustContrast"


class TiAnchorOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiAnchorOutline"


class TiAnchor(rx.Component):
    library = "react-icons/ti"
    tag = "TiAnchor"


class TiArchive(rx.Component):
    library = "react-icons/ti"
    tag = "TiArchive"


class TiArrowBackOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiArrowBackOutline"


class TiArrowBack(rx.Component):
    library = "react-icons/ti"
    tag = "TiArrowBack"


class TiArrowDownOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiArrowDownOutline"


class TiArrowDownThick(rx.Component):
    library = "react-icons/ti"
    tag = "TiArrowDownThick"


class TiArrowDown(rx.Component):
    library = "react-icons/ti"
    tag = "TiArrowDown"


class TiArrowForwardOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiArrowForwardOutline"


class TiArrowForward(rx.Component):
    library = "react-icons/ti"
    tag = "TiArrowForward"


class TiArrowLeftOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiArrowLeftOutline"


class TiArrowLeftThick(rx.Component):
    library = "react-icons/ti"
    tag = "TiArrowLeftThick"


class TiArrowLeft(rx.Component):
    library = "react-icons/ti"
    tag = "TiArrowLeft"


class TiArrowLoopOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiArrowLoopOutline"


class TiArrowLoop(rx.Component):
    library = "react-icons/ti"
    tag = "TiArrowLoop"


class TiArrowMaximiseOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiArrowMaximiseOutline"


class TiArrowMaximise(rx.Component):
    library = "react-icons/ti"
    tag = "TiArrowMaximise"


class TiArrowMinimiseOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiArrowMinimiseOutline"


class TiArrowMinimise(rx.Component):
    library = "react-icons/ti"
    tag = "TiArrowMinimise"


class TiArrowMoveOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiArrowMoveOutline"


class TiArrowMove(rx.Component):
    library = "react-icons/ti"
    tag = "TiArrowMove"


class TiArrowRepeatOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiArrowRepeatOutline"


class TiArrowRepeat(rx.Component):
    library = "react-icons/ti"
    tag = "TiArrowRepeat"


class TiArrowRightOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiArrowRightOutline"


class TiArrowRightThick(rx.Component):
    library = "react-icons/ti"
    tag = "TiArrowRightThick"


class TiArrowRight(rx.Component):
    library = "react-icons/ti"
    tag = "TiArrowRight"


class TiArrowShuffle(rx.Component):
    library = "react-icons/ti"
    tag = "TiArrowShuffle"


class TiArrowSortedDown(rx.Component):
    library = "react-icons/ti"
    tag = "TiArrowSortedDown"


class TiArrowSortedUp(rx.Component):
    library = "react-icons/ti"
    tag = "TiArrowSortedUp"


class TiArrowSyncOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiArrowSyncOutline"


class TiArrowSync(rx.Component):
    library = "react-icons/ti"
    tag = "TiArrowSync"


class TiArrowUnsorted(rx.Component):
    library = "react-icons/ti"
    tag = "TiArrowUnsorted"


class TiArrowUpOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiArrowUpOutline"


class TiArrowUpThick(rx.Component):
    library = "react-icons/ti"
    tag = "TiArrowUpThick"


class TiArrowUp(rx.Component):
    library = "react-icons/ti"
    tag = "TiArrowUp"


class TiAt(rx.Component):
    library = "react-icons/ti"
    tag = "TiAt"


class TiAttachmentOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiAttachmentOutline"


class TiAttachment(rx.Component):
    library = "react-icons/ti"
    tag = "TiAttachment"


class TiBackspaceOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiBackspaceOutline"


class TiBackspace(rx.Component):
    library = "react-icons/ti"
    tag = "TiBackspace"


class TiBatteryCharge(rx.Component):
    library = "react-icons/ti"
    tag = "TiBatteryCharge"


class TiBatteryFull(rx.Component):
    library = "react-icons/ti"
    tag = "TiBatteryFull"


class TiBatteryHigh(rx.Component):
    library = "react-icons/ti"
    tag = "TiBatteryHigh"


class TiBatteryLow(rx.Component):
    library = "react-icons/ti"
    tag = "TiBatteryLow"


class TiBatteryMid(rx.Component):
    library = "react-icons/ti"
    tag = "TiBatteryMid"


class TiBeaker(rx.Component):
    library = "react-icons/ti"
    tag = "TiBeaker"


class TiBeer(rx.Component):
    library = "react-icons/ti"
    tag = "TiBeer"


class TiBell(rx.Component):
    library = "react-icons/ti"
    tag = "TiBell"


class TiBook(rx.Component):
    library = "react-icons/ti"
    tag = "TiBook"


class TiBookmark(rx.Component):
    library = "react-icons/ti"
    tag = "TiBookmark"


class TiBriefcase(rx.Component):
    library = "react-icons/ti"
    tag = "TiBriefcase"


class TiBrush(rx.Component):
    library = "react-icons/ti"
    tag = "TiBrush"


class TiBusinessCard(rx.Component):
    library = "react-icons/ti"
    tag = "TiBusinessCard"


class TiCalculator(rx.Component):
    library = "react-icons/ti"
    tag = "TiCalculator"


class TiCalendarOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiCalendarOutline"


class TiCalendar(rx.Component):
    library = "react-icons/ti"
    tag = "TiCalendar"


class TiCameraOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiCameraOutline"


class TiCamera(rx.Component):
    library = "react-icons/ti"
    tag = "TiCamera"


class TiCancelOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiCancelOutline"


class TiCancel(rx.Component):
    library = "react-icons/ti"
    tag = "TiCancel"


class TiChartAreaOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiChartAreaOutline"


class TiChartArea(rx.Component):
    library = "react-icons/ti"
    tag = "TiChartArea"


class TiChartBarOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiChartBarOutline"


class TiChartBar(rx.Component):
    library = "react-icons/ti"
    tag = "TiChartBar"


class TiChartLineOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiChartLineOutline"


class TiChartLine(rx.Component):
    library = "react-icons/ti"
    tag = "TiChartLine"


class TiChartPieOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiChartPieOutline"


class TiChartPie(rx.Component):
    library = "react-icons/ti"
    tag = "TiChartPie"


class TiChevronLeftOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiChevronLeftOutline"


class TiChevronLeft(rx.Component):
    library = "react-icons/ti"
    tag = "TiChevronLeft"


class TiChevronRightOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiChevronRightOutline"


class TiChevronRight(rx.Component):
    library = "react-icons/ti"
    tag = "TiChevronRight"


class TiClipboard(rx.Component):
    library = "react-icons/ti"
    tag = "TiClipboard"


class TiCloudStorageOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiCloudStorageOutline"


class TiCloudStorage(rx.Component):
    library = "react-icons/ti"
    tag = "TiCloudStorage"


class TiCodeOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiCodeOutline"


class TiCode(rx.Component):
    library = "react-icons/ti"
    tag = "TiCode"


class TiCoffee(rx.Component):
    library = "react-icons/ti"
    tag = "TiCoffee"


class TiCogOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiCogOutline"


class TiCog(rx.Component):
    library = "react-icons/ti"
    tag = "TiCog"


class TiCompass(rx.Component):
    library = "react-icons/ti"
    tag = "TiCompass"


class TiContacts(rx.Component):
    library = "react-icons/ti"
    tag = "TiContacts"


class TiCreditCard(rx.Component):
    library = "react-icons/ti"
    tag = "TiCreditCard"


class TiCss3(rx.Component):
    library = "react-icons/ti"
    tag = "TiCss3"


class TiDatabase(rx.Component):
    library = "react-icons/ti"
    tag = "TiDatabase"


class TiDeleteOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiDeleteOutline"


class TiDelete(rx.Component):
    library = "react-icons/ti"
    tag = "TiDelete"


class TiDeviceDesktop(rx.Component):
    library = "react-icons/ti"
    tag = "TiDeviceDesktop"


class TiDeviceLaptop(rx.Component):
    library = "react-icons/ti"
    tag = "TiDeviceLaptop"


class TiDevicePhone(rx.Component):
    library = "react-icons/ti"
    tag = "TiDevicePhone"


class TiDeviceTablet(rx.Component):
    library = "react-icons/ti"
    tag = "TiDeviceTablet"


class TiDirections(rx.Component):
    library = "react-icons/ti"
    tag = "TiDirections"


class TiDivideOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiDivideOutline"


class TiDivide(rx.Component):
    library = "react-icons/ti"
    tag = "TiDivide"


class TiDocumentAdd(rx.Component):
    library = "react-icons/ti"
    tag = "TiDocumentAdd"


class TiDocumentDelete(rx.Component):
    library = "react-icons/ti"
    tag = "TiDocumentDelete"


class TiDocumentText(rx.Component):
    library = "react-icons/ti"
    tag = "TiDocumentText"


class TiDocument(rx.Component):
    library = "react-icons/ti"
    tag = "TiDocument"


class TiDownloadOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiDownloadOutline"


class TiDownload(rx.Component):
    library = "react-icons/ti"
    tag = "TiDownload"


class TiDropbox(rx.Component):
    library = "react-icons/ti"
    tag = "TiDropbox"


class TiEdit(rx.Component):
    library = "react-icons/ti"
    tag = "TiEdit"


class TiEjectOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiEjectOutline"


class TiEject(rx.Component):
    library = "react-icons/ti"
    tag = "TiEject"


class TiEqualsOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiEqualsOutline"


class TiEquals(rx.Component):
    library = "react-icons/ti"
    tag = "TiEquals"


class TiExportOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiExportOutline"


class TiExport(rx.Component):
    library = "react-icons/ti"
    tag = "TiExport"


class TiEyeOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiEyeOutline"


class TiEye(rx.Component):
    library = "react-icons/ti"
    tag = "TiEye"


class TiFeather(rx.Component):
    library = "react-icons/ti"
    tag = "TiFeather"


class TiFilm(rx.Component):
    library = "react-icons/ti"
    tag = "TiFilm"


class TiFilter(rx.Component):
    library = "react-icons/ti"
    tag = "TiFilter"


class TiFlagOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiFlagOutline"


class TiFlag(rx.Component):
    library = "react-icons/ti"
    tag = "TiFlag"


class TiFlashOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiFlashOutline"


class TiFlash(rx.Component):
    library = "react-icons/ti"
    tag = "TiFlash"


class TiFlowChildren(rx.Component):
    library = "react-icons/ti"
    tag = "TiFlowChildren"


class TiFlowMerge(rx.Component):
    library = "react-icons/ti"
    tag = "TiFlowMerge"


class TiFlowParallel(rx.Component):
    library = "react-icons/ti"
    tag = "TiFlowParallel"


class TiFlowSwitch(rx.Component):
    library = "react-icons/ti"
    tag = "TiFlowSwitch"


class TiFolderAdd(rx.Component):
    library = "react-icons/ti"
    tag = "TiFolderAdd"


class TiFolderDelete(rx.Component):
    library = "react-icons/ti"
    tag = "TiFolderDelete"


class TiFolderOpen(rx.Component):
    library = "react-icons/ti"
    tag = "TiFolderOpen"


class TiFolder(rx.Component):
    library = "react-icons/ti"
    tag = "TiFolder"


class TiGift(rx.Component):
    library = "react-icons/ti"
    tag = "TiGift"


class TiGlobeOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiGlobeOutline"


class TiGlobe(rx.Component):
    library = "react-icons/ti"
    tag = "TiGlobe"


class TiGroupOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiGroupOutline"


class TiGroup(rx.Component):
    library = "react-icons/ti"
    tag = "TiGroup"


class TiHeadphones(rx.Component):
    library = "react-icons/ti"
    tag = "TiHeadphones"


class TiHeartFullOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiHeartFullOutline"


class TiHeartHalfOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiHeartHalfOutline"


class TiHeartOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiHeartOutline"


class TiHeart(rx.Component):
    library = "react-icons/ti"
    tag = "TiHeart"


class TiHomeOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiHomeOutline"


class TiHome(rx.Component):
    library = "react-icons/ti"
    tag = "TiHome"


class TiHtml5(rx.Component):
    library = "react-icons/ti"
    tag = "TiHtml5"


class TiImageOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiImageOutline"


class TiImage(rx.Component):
    library = "react-icons/ti"
    tag = "TiImage"


class TiInfinityOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiInfinityOutline"


class TiInfinity(rx.Component):
    library = "react-icons/ti"
    tag = "TiInfinity"


class TiInfoLargeOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiInfoLargeOutline"


class TiInfoLarge(rx.Component):
    library = "react-icons/ti"
    tag = "TiInfoLarge"


class TiInfoOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiInfoOutline"


class TiInfo(rx.Component):
    library = "react-icons/ti"
    tag = "TiInfo"


class TiInputCheckedOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiInputCheckedOutline"


class TiInputChecked(rx.Component):
    library = "react-icons/ti"
    tag = "TiInputChecked"


class TiKeyOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiKeyOutline"


class TiKey(rx.Component):
    library = "react-icons/ti"
    tag = "TiKey"


class TiKeyboard(rx.Component):
    library = "react-icons/ti"
    tag = "TiKeyboard"


class TiLeaf(rx.Component):
    library = "react-icons/ti"
    tag = "TiLeaf"


class TiLightbulb(rx.Component):
    library = "react-icons/ti"
    tag = "TiLightbulb"


class TiLinkOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiLinkOutline"


class TiLink(rx.Component):
    library = "react-icons/ti"
    tag = "TiLink"


class TiLocationArrowOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiLocationArrowOutline"


class TiLocationArrow(rx.Component):
    library = "react-icons/ti"
    tag = "TiLocationArrow"


class TiLocationOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiLocationOutline"


class TiLocation(rx.Component):
    library = "react-icons/ti"
    tag = "TiLocation"


class TiLockClosedOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiLockClosedOutline"


class TiLockClosed(rx.Component):
    library = "react-icons/ti"
    tag = "TiLockClosed"


class TiLockOpenOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiLockOpenOutline"


class TiLockOpen(rx.Component):
    library = "react-icons/ti"
    tag = "TiLockOpen"


class TiMail(rx.Component):
    library = "react-icons/ti"
    tag = "TiMail"


class TiMap(rx.Component):
    library = "react-icons/ti"
    tag = "TiMap"


class TiMediaEjectOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiMediaEjectOutline"


class TiMediaEject(rx.Component):
    library = "react-icons/ti"
    tag = "TiMediaEject"


class TiMediaFastForwardOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiMediaFastForwardOutline"


class TiMediaFastForward(rx.Component):
    library = "react-icons/ti"
    tag = "TiMediaFastForward"


class TiMediaPauseOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiMediaPauseOutline"


class TiMediaPause(rx.Component):
    library = "react-icons/ti"
    tag = "TiMediaPause"


class TiMediaPlayOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiMediaPlayOutline"


class TiMediaPlayReverseOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiMediaPlayReverseOutline"


class TiMediaPlayReverse(rx.Component):
    library = "react-icons/ti"
    tag = "TiMediaPlayReverse"


class TiMediaPlay(rx.Component):
    library = "react-icons/ti"
    tag = "TiMediaPlay"


class TiMediaRecordOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiMediaRecordOutline"


class TiMediaRecord(rx.Component):
    library = "react-icons/ti"
    tag = "TiMediaRecord"


class TiMediaRewindOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiMediaRewindOutline"


class TiMediaRewind(rx.Component):
    library = "react-icons/ti"
    tag = "TiMediaRewind"


class TiMediaStopOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiMediaStopOutline"


class TiMediaStop(rx.Component):
    library = "react-icons/ti"
    tag = "TiMediaStop"


class TiMessageTyping(rx.Component):
    library = "react-icons/ti"
    tag = "TiMessageTyping"


class TiMessage(rx.Component):
    library = "react-icons/ti"
    tag = "TiMessage"


class TiMessages(rx.Component):
    library = "react-icons/ti"
    tag = "TiMessages"


class TiMicrophoneOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiMicrophoneOutline"


class TiMicrophone(rx.Component):
    library = "react-icons/ti"
    tag = "TiMicrophone"


class TiMinusOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiMinusOutline"


class TiMinus(rx.Component):
    library = "react-icons/ti"
    tag = "TiMinus"


class TiMortarBoard(rx.Component):
    library = "react-icons/ti"
    tag = "TiMortarBoard"


class TiNews(rx.Component):
    library = "react-icons/ti"
    tag = "TiNews"


class TiNotesOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiNotesOutline"


class TiNotes(rx.Component):
    library = "react-icons/ti"
    tag = "TiNotes"


class TiPen(rx.Component):
    library = "react-icons/ti"
    tag = "TiPen"


class TiPencil(rx.Component):
    library = "react-icons/ti"
    tag = "TiPencil"


class TiPhoneOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiPhoneOutline"


class TiPhone(rx.Component):
    library = "react-icons/ti"
    tag = "TiPhone"


class TiPiOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiPiOutline"


class TiPi(rx.Component):
    library = "react-icons/ti"
    tag = "TiPi"


class TiPinOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiPinOutline"


class TiPin(rx.Component):
    library = "react-icons/ti"
    tag = "TiPin"


class TiPipette(rx.Component):
    library = "react-icons/ti"
    tag = "TiPipette"


class TiPlaneOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiPlaneOutline"


class TiPlane(rx.Component):
    library = "react-icons/ti"
    tag = "TiPlane"


class TiPlug(rx.Component):
    library = "react-icons/ti"
    tag = "TiPlug"


class TiPlusOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiPlusOutline"


class TiPlus(rx.Component):
    library = "react-icons/ti"
    tag = "TiPlus"


class TiPointOfInterestOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiPointOfInterestOutline"


class TiPointOfInterest(rx.Component):
    library = "react-icons/ti"
    tag = "TiPointOfInterest"


class TiPowerOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiPowerOutline"


class TiPower(rx.Component):
    library = "react-icons/ti"
    tag = "TiPower"


class TiPrinter(rx.Component):
    library = "react-icons/ti"
    tag = "TiPrinter"


class TiPuzzleOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiPuzzleOutline"


class TiPuzzle(rx.Component):
    library = "react-icons/ti"
    tag = "TiPuzzle"


class TiRadarOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiRadarOutline"


class TiRadar(rx.Component):
    library = "react-icons/ti"
    tag = "TiRadar"


class TiRefreshOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiRefreshOutline"


class TiRefresh(rx.Component):
    library = "react-icons/ti"
    tag = "TiRefresh"


class TiRssOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiRssOutline"


class TiRss(rx.Component):
    library = "react-icons/ti"
    tag = "TiRss"


class TiScissorsOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiScissorsOutline"


class TiScissors(rx.Component):
    library = "react-icons/ti"
    tag = "TiScissors"


class TiShoppingBag(rx.Component):
    library = "react-icons/ti"
    tag = "TiShoppingBag"


class TiShoppingCart(rx.Component):
    library = "react-icons/ti"
    tag = "TiShoppingCart"


class TiSocialAtCircular(rx.Component):
    library = "react-icons/ti"
    tag = "TiSocialAtCircular"


class TiSocialDribbbleCircular(rx.Component):
    library = "react-icons/ti"
    tag = "TiSocialDribbbleCircular"


class TiSocialDribbble(rx.Component):
    library = "react-icons/ti"
    tag = "TiSocialDribbble"


class TiSocialFacebookCircular(rx.Component):
    library = "react-icons/ti"
    tag = "TiSocialFacebookCircular"


class TiSocialFacebook(rx.Component):
    library = "react-icons/ti"
    tag = "TiSocialFacebook"


class TiSocialFlickrCircular(rx.Component):
    library = "react-icons/ti"
    tag = "TiSocialFlickrCircular"


class TiSocialFlickr(rx.Component):
    library = "react-icons/ti"
    tag = "TiSocialFlickr"


class TiSocialGithubCircular(rx.Component):
    library = "react-icons/ti"
    tag = "TiSocialGithubCircular"


class TiSocialGithub(rx.Component):
    library = "react-icons/ti"
    tag = "TiSocialGithub"


class TiSocialGooglePlusCircular(rx.Component):
    library = "react-icons/ti"
    tag = "TiSocialGooglePlusCircular"


class TiSocialGooglePlus(rx.Component):
    library = "react-icons/ti"
    tag = "TiSocialGooglePlus"


class TiSocialInstagramCircular(rx.Component):
    library = "react-icons/ti"
    tag = "TiSocialInstagramCircular"


class TiSocialInstagram(rx.Component):
    library = "react-icons/ti"
    tag = "TiSocialInstagram"


class TiSocialLastFmCircular(rx.Component):
    library = "react-icons/ti"
    tag = "TiSocialLastFmCircular"


class TiSocialLastFm(rx.Component):
    library = "react-icons/ti"
    tag = "TiSocialLastFm"


class TiSocialLinkedinCircular(rx.Component):
    library = "react-icons/ti"
    tag = "TiSocialLinkedinCircular"


class TiSocialLinkedin(rx.Component):
    library = "react-icons/ti"
    tag = "TiSocialLinkedin"


class TiSocialPinterestCircular(rx.Component):
    library = "react-icons/ti"
    tag = "TiSocialPinterestCircular"


class TiSocialPinterest(rx.Component):
    library = "react-icons/ti"
    tag = "TiSocialPinterest"


class TiSocialSkypeOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiSocialSkypeOutline"


class TiSocialSkype(rx.Component):
    library = "react-icons/ti"
    tag = "TiSocialSkype"


class TiSocialTumblerCircular(rx.Component):
    library = "react-icons/ti"
    tag = "TiSocialTumblerCircular"


class TiSocialTumbler(rx.Component):
    library = "react-icons/ti"
    tag = "TiSocialTumbler"


class TiSocialTwitterCircular(rx.Component):
    library = "react-icons/ti"
    tag = "TiSocialTwitterCircular"


class TiSocialTwitter(rx.Component):
    library = "react-icons/ti"
    tag = "TiSocialTwitter"


class TiSocialVimeoCircular(rx.Component):
    library = "react-icons/ti"
    tag = "TiSocialVimeoCircular"


class TiSocialVimeo(rx.Component):
    library = "react-icons/ti"
    tag = "TiSocialVimeo"


class TiSocialYoutubeCircular(rx.Component):
    library = "react-icons/ti"
    tag = "TiSocialYoutubeCircular"


class TiSocialYoutube(rx.Component):
    library = "react-icons/ti"
    tag = "TiSocialYoutube"


class TiSortAlphabeticallyOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiSortAlphabeticallyOutline"


class TiSortAlphabetically(rx.Component):
    library = "react-icons/ti"
    tag = "TiSortAlphabetically"


class TiSortNumericallyOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiSortNumericallyOutline"


class TiSortNumerically(rx.Component):
    library = "react-icons/ti"
    tag = "TiSortNumerically"


class TiSpannerOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiSpannerOutline"


class TiSpanner(rx.Component):
    library = "react-icons/ti"
    tag = "TiSpanner"


class TiSpiral(rx.Component):
    library = "react-icons/ti"
    tag = "TiSpiral"


class TiStarFullOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiStarFullOutline"


class TiStarHalfOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiStarHalfOutline"


class TiStarHalf(rx.Component):
    library = "react-icons/ti"
    tag = "TiStarHalf"


class TiStarOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiStarOutline"


class TiStar(rx.Component):
    library = "react-icons/ti"
    tag = "TiStar"


class TiStarburstOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiStarburstOutline"


class TiStarburst(rx.Component):
    library = "react-icons/ti"
    tag = "TiStarburst"


class TiStopwatch(rx.Component):
    library = "react-icons/ti"
    tag = "TiStopwatch"


class TiSupport(rx.Component):
    library = "react-icons/ti"
    tag = "TiSupport"


class TiTabsOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiTabsOutline"


class TiTag(rx.Component):
    library = "react-icons/ti"
    tag = "TiTag"


class TiTags(rx.Component):
    library = "react-icons/ti"
    tag = "TiTags"


class TiThLargeOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiThLargeOutline"


class TiThLarge(rx.Component):
    library = "react-icons/ti"
    tag = "TiThLarge"


class TiThListOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiThListOutline"


class TiThList(rx.Component):
    library = "react-icons/ti"
    tag = "TiThList"


class TiThMenuOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiThMenuOutline"


class TiThMenu(rx.Component):
    library = "react-icons/ti"
    tag = "TiThMenu"


class TiThSmallOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiThSmallOutline"


class TiThSmall(rx.Component):
    library = "react-icons/ti"
    tag = "TiThSmall"


class TiThermometer(rx.Component):
    library = "react-icons/ti"
    tag = "TiThermometer"


class TiThumbsDown(rx.Component):
    library = "react-icons/ti"
    tag = "TiThumbsDown"


class TiThumbsOk(rx.Component):
    library = "react-icons/ti"
    tag = "TiThumbsOk"


class TiThumbsUp(rx.Component):
    library = "react-icons/ti"
    tag = "TiThumbsUp"


class TiTickOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiTickOutline"


class TiTick(rx.Component):
    library = "react-icons/ti"
    tag = "TiTick"


class TiTicket(rx.Component):
    library = "react-icons/ti"
    tag = "TiTicket"


class TiTime(rx.Component):
    library = "react-icons/ti"
    tag = "TiTime"


class TiTimesOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiTimesOutline"


class TiTimes(rx.Component):
    library = "react-icons/ti"
    tag = "TiTimes"


class TiTrash(rx.Component):
    library = "react-icons/ti"
    tag = "TiTrash"


class TiTree(rx.Component):
    library = "react-icons/ti"
    tag = "TiTree"


class TiUploadOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiUploadOutline"


class TiUpload(rx.Component):
    library = "react-icons/ti"
    tag = "TiUpload"


class TiUserAddOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiUserAddOutline"


class TiUserAdd(rx.Component):
    library = "react-icons/ti"
    tag = "TiUserAdd"


class TiUserDeleteOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiUserDeleteOutline"


class TiUserDelete(rx.Component):
    library = "react-icons/ti"
    tag = "TiUserDelete"


class TiUserOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiUserOutline"


class TiUser(rx.Component):
    library = "react-icons/ti"
    tag = "TiUser"


class TiVendorAndroid(rx.Component):
    library = "react-icons/ti"
    tag = "TiVendorAndroid"


class TiVendorApple(rx.Component):
    library = "react-icons/ti"
    tag = "TiVendorApple"


class TiVendorMicrosoft(rx.Component):
    library = "react-icons/ti"
    tag = "TiVendorMicrosoft"


class TiVideoOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiVideoOutline"


class TiVideo(rx.Component):
    library = "react-icons/ti"
    tag = "TiVideo"


class TiVolumeDown(rx.Component):
    library = "react-icons/ti"
    tag = "TiVolumeDown"


class TiVolumeMute(rx.Component):
    library = "react-icons/ti"
    tag = "TiVolumeMute"


class TiVolumeUp(rx.Component):
    library = "react-icons/ti"
    tag = "TiVolumeUp"


class TiVolume(rx.Component):
    library = "react-icons/ti"
    tag = "TiVolume"


class TiWarningOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiWarningOutline"


class TiWarning(rx.Component):
    library = "react-icons/ti"
    tag = "TiWarning"


class TiWatch(rx.Component):
    library = "react-icons/ti"
    tag = "TiWatch"


class TiWavesOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiWavesOutline"


class TiWaves(rx.Component):
    library = "react-icons/ti"
    tag = "TiWaves"


class TiWeatherCloudy(rx.Component):
    library = "react-icons/ti"
    tag = "TiWeatherCloudy"


class TiWeatherDownpour(rx.Component):
    library = "react-icons/ti"
    tag = "TiWeatherDownpour"


class TiWeatherNight(rx.Component):
    library = "react-icons/ti"
    tag = "TiWeatherNight"


class TiWeatherPartlySunny(rx.Component):
    library = "react-icons/ti"
    tag = "TiWeatherPartlySunny"


class TiWeatherShower(rx.Component):
    library = "react-icons/ti"
    tag = "TiWeatherShower"


class TiWeatherSnow(rx.Component):
    library = "react-icons/ti"
    tag = "TiWeatherSnow"


class TiWeatherStormy(rx.Component):
    library = "react-icons/ti"
    tag = "TiWeatherStormy"


class TiWeatherSunny(rx.Component):
    library = "react-icons/ti"
    tag = "TiWeatherSunny"


class TiWeatherWindyCloudy(rx.Component):
    library = "react-icons/ti"
    tag = "TiWeatherWindyCloudy"


class TiWeatherWindy(rx.Component):
    library = "react-icons/ti"
    tag = "TiWeatherWindy"


class TiWiFiOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiWiFiOutline"


class TiWiFi(rx.Component):
    library = "react-icons/ti"
    tag = "TiWiFi"


class TiWine(rx.Component):
    library = "react-icons/ti"
    tag = "TiWine"


class TiWorldOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiWorldOutline"


class TiWorld(rx.Component):
    library = "react-icons/ti"
    tag = "TiWorld"


class TiZoomInOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiZoomInOutline"


class TiZoomIn(rx.Component):
    library = "react-icons/ti"
    tag = "TiZoomIn"


class TiZoomOutOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiZoomOutOutline"


class TiZoomOut(rx.Component):
    library = "react-icons/ti"
    tag = "TiZoomOut"


class TiZoomOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiZoomOutline"


class TiZoom(rx.Component):
    library = "react-icons/ti"
    tag = "TiZoom"





import reflex as rx

class CgAbstract(rx.Component):
    library = "react-icons/cg"
    tag = "CgAbstract"


class CgAddR(rx.Component):
    library = "react-icons/cg"
    tag = "CgAddR"


class CgAdd(rx.Component):
    library = "react-icons/cg"
    tag = "CgAdd"


class CgAdidas(rx.Component):
    library = "react-icons/cg"
    tag = "CgAdidas"


class CgAirplane(rx.Component):
    library = "react-icons/cg"
    tag = "CgAirplane"


class CgAlarm(rx.Component):
    library = "react-icons/cg"
    tag = "CgAlarm"


class CgAlbum(rx.Component):
    library = "react-icons/cg"
    tag = "CgAlbum"


class CgAlignBottom(rx.Component):
    library = "react-icons/cg"
    tag = "CgAlignBottom"


class CgAlignCenter(rx.Component):
    library = "react-icons/cg"
    tag = "CgAlignCenter"


class CgAlignLeft(rx.Component):
    library = "react-icons/cg"
    tag = "CgAlignLeft"


class CgAlignMiddle(rx.Component):
    library = "react-icons/cg"
    tag = "CgAlignMiddle"


class CgAlignRight(rx.Component):
    library = "react-icons/cg"
    tag = "CgAlignRight"


class CgAlignTop(rx.Component):
    library = "react-icons/cg"
    tag = "CgAlignTop"


class CgAnchor(rx.Component):
    library = "react-icons/cg"
    tag = "CgAnchor"


class CgAppleWatch(rx.Component):
    library = "react-icons/cg"
    tag = "CgAppleWatch"


class CgArrangeBack(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrangeBack"


class CgArrangeFront(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrangeFront"


class CgArrowAlignH(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowAlignH"


class CgArrowAlignV(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowAlignV"


class CgArrowBottomLeftO(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowBottomLeftO"


class CgArrowBottomLeftR(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowBottomLeftR"


class CgArrowBottomLeft(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowBottomLeft"


class CgArrowBottomRightO(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowBottomRightO"


class CgArrowBottomRightR(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowBottomRightR"


class CgArrowBottomRight(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowBottomRight"


class CgArrowDownO(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowDownO"


class CgArrowDownR(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowDownR"


class CgArrowDown(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowDown"


class CgArrowLeftO(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowLeftO"


class CgArrowLeftR(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowLeftR"


class CgArrowLeft(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowLeft"


class CgArrowLongDownC(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowLongDownC"


class CgArrowLongDownE(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowLongDownE"


class CgArrowLongDownL(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowLongDownL"


class CgArrowLongDownR(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowLongDownR"


class CgArrowLongDown(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowLongDown"


class CgArrowLongLeftC(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowLongLeftC"


class CgArrowLongLeftE(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowLongLeftE"


class CgArrowLongLeftL(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowLongLeftL"


class CgArrowLongLeftR(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowLongLeftR"


class CgArrowLongLeft(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowLongLeft"


class CgArrowLongRightC(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowLongRightC"


class CgArrowLongRightE(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowLongRightE"


class CgArrowLongRightL(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowLongRightL"


class CgArrowLongRightR(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowLongRightR"


class CgArrowLongRight(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowLongRight"


class CgArrowLongUpC(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowLongUpC"


class CgArrowLongUpE(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowLongUpE"


class CgArrowLongUpL(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowLongUpL"


class CgArrowLongUpR(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowLongUpR"


class CgArrowLongUp(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowLongUp"


class CgArrowRightO(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowRightO"


class CgArrowRightR(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowRightR"


class CgArrowRight(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowRight"


class CgArrowTopLeftO(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowTopLeftO"


class CgArrowTopLeftR(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowTopLeftR"


class CgArrowTopLeft(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowTopLeft"


class CgArrowTopRightO(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowTopRightO"


class CgArrowTopRightR(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowTopRightR"


class CgArrowTopRight(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowTopRight"


class CgArrowUpO(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowUpO"


class CgArrowUpR(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowUpR"


class CgArrowUp(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowUp"


class CgArrowsBreakeH(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowsBreakeH"


class CgArrowsBreakeV(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowsBreakeV"


class CgArrowsExchangeAltV(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowsExchangeAltV"


class CgArrowsExchangeAlt(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowsExchangeAlt"


class CgArrowsExchangeV(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowsExchangeV"


class CgArrowsExchange(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowsExchange"


class CgArrowsExpandDownLeft(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowsExpandDownLeft"


class CgArrowsExpandDownRight(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowsExpandDownRight"


class CgArrowsExpandLeftAlt(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowsExpandLeftAlt"


class CgArrowsExpandLeft(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowsExpandLeft"


class CgArrowsExpandRightAlt(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowsExpandRightAlt"


class CgArrowsExpandRight(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowsExpandRight"


class CgArrowsExpandUpLeft(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowsExpandUpLeft"


class CgArrowsExpandUpRight(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowsExpandUpRight"


class CgArrowsHAlt(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowsHAlt"


class CgArrowsH(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowsH"


class CgArrowsMergeAltH(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowsMergeAltH"


class CgArrowsMergeAltV(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowsMergeAltV"


class CgArrowsScrollH(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowsScrollH"


class CgArrowsScrollV(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowsScrollV"


class CgArrowsShrinkH(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowsShrinkH"


class CgArrowsShrinkV(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowsShrinkV"


class CgArrowsVAlt(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowsVAlt"


class CgArrowsV(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowsV"


class CgAssign(rx.Component):
    library = "react-icons/cg"
    tag = "CgAssign"


class CgAsterisk(rx.Component):
    library = "react-icons/cg"
    tag = "CgAsterisk"


class CgAtlasian(rx.Component):
    library = "react-icons/cg"
    tag = "CgAtlasian"


class CgAttachment(rx.Component):
    library = "react-icons/cg"
    tag = "CgAttachment"


class CgAttribution(rx.Component):
    library = "react-icons/cg"
    tag = "CgAttribution"


class CgAwards(rx.Component):
    library = "react-icons/cg"
    tag = "CgAwards"


class CgBackspace(rx.Component):
    library = "react-icons/cg"
    tag = "CgBackspace"


class CgBandAid(rx.Component):
    library = "react-icons/cg"
    tag = "CgBandAid"


class CgBatteryEmpty(rx.Component):
    library = "react-icons/cg"
    tag = "CgBatteryEmpty"


class CgBatteryFull(rx.Component):
    library = "react-icons/cg"
    tag = "CgBatteryFull"


class CgBattery(rx.Component):
    library = "react-icons/cg"
    tag = "CgBattery"


class CgBee(rx.Component):
    library = "react-icons/cg"
    tag = "CgBee"


class CgBell(rx.Component):
    library = "react-icons/cg"
    tag = "CgBell"


class CgBitbucket(rx.Component):
    library = "react-icons/cg"
    tag = "CgBitbucket"


class CgBlock(rx.Component):
    library = "react-icons/cg"
    tag = "CgBlock"


class CgBmw(rx.Component):
    library = "react-icons/cg"
    tag = "CgBmw"


class CgBoard(rx.Component):
    library = "react-icons/cg"
    tag = "CgBoard"


class CgBolt(rx.Component):
    library = "react-icons/cg"
    tag = "CgBolt"


class CgBookmark(rx.Component):
    library = "react-icons/cg"
    tag = "CgBookmark"


class CgBorderAll(rx.Component):
    library = "react-icons/cg"
    tag = "CgBorderAll"


class CgBorderBottom(rx.Component):
    library = "react-icons/cg"
    tag = "CgBorderBottom"


class CgBorderLeft(rx.Component):
    library = "react-icons/cg"
    tag = "CgBorderLeft"


class CgBorderRight(rx.Component):
    library = "react-icons/cg"
    tag = "CgBorderRight"


class CgBorderStyleDashed(rx.Component):
    library = "react-icons/cg"
    tag = "CgBorderStyleDashed"


class CgBorderStyleDotted(rx.Component):
    library = "react-icons/cg"
    tag = "CgBorderStyleDotted"


class CgBorderStyleSolid(rx.Component):
    library = "react-icons/cg"
    tag = "CgBorderStyleSolid"


class CgBorderTop(rx.Component):
    library = "react-icons/cg"
    tag = "CgBorderTop"


class CgBot(rx.Component):
    library = "react-icons/cg"
    tag = "CgBot"


class CgBowl(rx.Component):
    library = "react-icons/cg"
    tag = "CgBowl"


class CgBox(rx.Component):
    library = "react-icons/cg"
    tag = "CgBox"


class CgBoy(rx.Component):
    library = "react-icons/cg"
    tag = "CgBoy"


class CgBrackets(rx.Component):
    library = "react-icons/cg"
    tag = "CgBrackets"


class CgBriefcase(rx.Component):
    library = "react-icons/cg"
    tag = "CgBriefcase"


class CgBrowse(rx.Component):
    library = "react-icons/cg"
    tag = "CgBrowse"


class CgBrowser(rx.Component):
    library = "react-icons/cg"
    tag = "CgBrowser"


class CgBrush(rx.Component):
    library = "react-icons/cg"
    tag = "CgBrush"


class CgBulb(rx.Component):
    library = "react-icons/cg"
    tag = "CgBulb"


class CgCPlusPlus(rx.Component):
    library = "react-icons/cg"
    tag = "CgCPlusPlus"


class CgCalculator(rx.Component):
    library = "react-icons/cg"
    tag = "CgCalculator"


class CgCalendarDates(rx.Component):
    library = "react-icons/cg"
    tag = "CgCalendarDates"


class CgCalendarDue(rx.Component):
    library = "react-icons/cg"
    tag = "CgCalendarDue"


class CgCalendarNext(rx.Component):
    library = "react-icons/cg"
    tag = "CgCalendarNext"


class CgCalendarToday(rx.Component):
    library = "react-icons/cg"
    tag = "CgCalendarToday"


class CgCalendarTwo(rx.Component):
    library = "react-icons/cg"
    tag = "CgCalendarTwo"


class CgCalendar(rx.Component):
    library = "react-icons/cg"
    tag = "CgCalendar"


class CgCalibrate(rx.Component):
    library = "react-icons/cg"
    tag = "CgCalibrate"


class CgCamera(rx.Component):
    library = "react-icons/cg"
    tag = "CgCamera"


class CgCap(rx.Component):
    library = "react-icons/cg"
    tag = "CgCap"


class CgCaptions(rx.Component):
    library = "react-icons/cg"
    tag = "CgCaptions"


class CgCardClubs(rx.Component):
    library = "react-icons/cg"
    tag = "CgCardClubs"


class CgCardDiamonds(rx.Component):
    library = "react-icons/cg"
    tag = "CgCardDiamonds"


class CgCardHearts(rx.Component):
    library = "react-icons/cg"
    tag = "CgCardHearts"


class CgCardSpades(rx.Component):
    library = "react-icons/cg"
    tag = "CgCardSpades"


class CgCarousel(rx.Component):
    library = "react-icons/cg"
    tag = "CgCarousel"


class CgCast(rx.Component):
    library = "react-icons/cg"
    tag = "CgCast"


class CgChanel(rx.Component):
    library = "react-icons/cg"
    tag = "CgChanel"


class CgChart(rx.Component):
    library = "react-icons/cg"
    tag = "CgChart"


class CgCheckO(rx.Component):
    library = "react-icons/cg"
    tag = "CgCheckO"


class CgCheckR(rx.Component):
    library = "react-icons/cg"
    tag = "CgCheckR"


class CgCheck(rx.Component):
    library = "react-icons/cg"
    tag = "CgCheck"


class CgChevronDoubleDownO(rx.Component):
    library = "react-icons/cg"
    tag = "CgChevronDoubleDownO"


class CgChevronDoubleDownR(rx.Component):
    library = "react-icons/cg"
    tag = "CgChevronDoubleDownR"


class CgChevronDoubleDown(rx.Component):
    library = "react-icons/cg"
    tag = "CgChevronDoubleDown"


class CgChevronDoubleLeftO(rx.Component):
    library = "react-icons/cg"
    tag = "CgChevronDoubleLeftO"


class CgChevronDoubleLeftR(rx.Component):
    library = "react-icons/cg"
    tag = "CgChevronDoubleLeftR"


class CgChevronDoubleLeft(rx.Component):
    library = "react-icons/cg"
    tag = "CgChevronDoubleLeft"


class CgChevronDoubleRightO(rx.Component):
    library = "react-icons/cg"
    tag = "CgChevronDoubleRightO"


class CgChevronDoubleRightR(rx.Component):
    library = "react-icons/cg"
    tag = "CgChevronDoubleRightR"


class CgChevronDoubleRight(rx.Component):
    library = "react-icons/cg"
    tag = "CgChevronDoubleRight"


class CgChevronDoubleUpO(rx.Component):
    library = "react-icons/cg"
    tag = "CgChevronDoubleUpO"


class CgChevronDoubleUpR(rx.Component):
    library = "react-icons/cg"
    tag = "CgChevronDoubleUpR"


class CgChevronDoubleUp(rx.Component):
    library = "react-icons/cg"
    tag = "CgChevronDoubleUp"


class CgChevronDownO(rx.Component):
    library = "react-icons/cg"
    tag = "CgChevronDownO"


class CgChevronDownR(rx.Component):
    library = "react-icons/cg"
    tag = "CgChevronDownR"


class CgChevronDown(rx.Component):
    library = "react-icons/cg"
    tag = "CgChevronDown"


class CgChevronLeftO(rx.Component):
    library = "react-icons/cg"
    tag = "CgChevronLeftO"


class CgChevronLeftR(rx.Component):
    library = "react-icons/cg"
    tag = "CgChevronLeftR"


class CgChevronLeft(rx.Component):
    library = "react-icons/cg"
    tag = "CgChevronLeft"


class CgChevronRightO(rx.Component):
    library = "react-icons/cg"
    tag = "CgChevronRightO"


class CgChevronRightR(rx.Component):
    library = "react-icons/cg"
    tag = "CgChevronRightR"


class CgChevronRight(rx.Component):
    library = "react-icons/cg"
    tag = "CgChevronRight"


class CgChevronUpO(rx.Component):
    library = "react-icons/cg"
    tag = "CgChevronUpO"


class CgChevronUpR(rx.Component):
    library = "react-icons/cg"
    tag = "CgChevronUpR"


class CgChevronUp(rx.Component):
    library = "react-icons/cg"
    tag = "CgChevronUp"


class CgCircleci(rx.Component):
    library = "react-icons/cg"
    tag = "CgCircleci"


class CgClapperBoard(rx.Component):
    library = "react-icons/cg"
    tag = "CgClapperBoard"


class CgClipboard(rx.Component):
    library = "react-icons/cg"
    tag = "CgClipboard"


class CgCloseO(rx.Component):
    library = "react-icons/cg"
    tag = "CgCloseO"


class CgCloseR(rx.Component):
    library = "react-icons/cg"
    tag = "CgCloseR"


class CgClose(rx.Component):
    library = "react-icons/cg"
    tag = "CgClose"


class CgCloud(rx.Component):
    library = "react-icons/cg"
    tag = "CgCloud"


class CgCodeClimate(rx.Component):
    library = "react-icons/cg"
    tag = "CgCodeClimate"


class CgCodeSlash(rx.Component):
    library = "react-icons/cg"
    tag = "CgCodeSlash"


class CgCode(rx.Component):
    library = "react-icons/cg"
    tag = "CgCode"


class CgCoffee(rx.Component):
    library = "react-icons/cg"
    tag = "CgCoffee"


class CgCollage(rx.Component):
    library = "react-icons/cg"
    tag = "CgCollage"


class CgColorBucket(rx.Component):
    library = "react-icons/cg"
    tag = "CgColorBucket"


class CgColorPicker(rx.Component):
    library = "react-icons/cg"
    tag = "CgColorPicker"


class CgComedyCentral(rx.Component):
    library = "react-icons/cg"
    tag = "CgComedyCentral"


class CgComment(rx.Component):
    library = "react-icons/cg"
    tag = "CgComment"


class CgCommunity(rx.Component):
    library = "react-icons/cg"
    tag = "CgCommunity"


class CgComponents(rx.Component):
    library = "react-icons/cg"
    tag = "CgComponents"


class CgCompressLeft(rx.Component):
    library = "react-icons/cg"
    tag = "CgCompressLeft"


class CgCompressRight(rx.Component):
    library = "react-icons/cg"
    tag = "CgCompressRight"


class CgCompressV(rx.Component):
    library = "react-icons/cg"
    tag = "CgCompressV"


class CgCompress(rx.Component):
    library = "react-icons/cg"
    tag = "CgCompress"


class CgController(rx.Component):
    library = "react-icons/cg"
    tag = "CgController"


class CgCopy(rx.Component):
    library = "react-icons/cg"
    tag = "CgCopy"


class CgCopyright(rx.Component):
    library = "react-icons/cg"
    tag = "CgCopyright"


class CgCornerDoubleDownLeft(rx.Component):
    library = "react-icons/cg"
    tag = "CgCornerDoubleDownLeft"


class CgCornerDoubleDownRight(rx.Component):
    library = "react-icons/cg"
    tag = "CgCornerDoubleDownRight"


class CgCornerDoubleLeftDown(rx.Component):
    library = "react-icons/cg"
    tag = "CgCornerDoubleLeftDown"


class CgCornerDoubleLeftUp(rx.Component):
    library = "react-icons/cg"
    tag = "CgCornerDoubleLeftUp"


class CgCornerDoubleRightDown(rx.Component):
    library = "react-icons/cg"
    tag = "CgCornerDoubleRightDown"


class CgCornerDoubleRightUp(rx.Component):
    library = "react-icons/cg"
    tag = "CgCornerDoubleRightUp"


class CgCornerDoubleUpLeft(rx.Component):
    library = "react-icons/cg"
    tag = "CgCornerDoubleUpLeft"


class CgCornerDoubleUpRight(rx.Component):
    library = "react-icons/cg"
    tag = "CgCornerDoubleUpRight"


class CgCornerDownLeft(rx.Component):
    library = "react-icons/cg"
    tag = "CgCornerDownLeft"


class CgCornerDownRight(rx.Component):
    library = "react-icons/cg"
    tag = "CgCornerDownRight"


class CgCornerLeftDown(rx.Component):
    library = "react-icons/cg"
    tag = "CgCornerLeftDown"


class CgCornerLeftUp(rx.Component):
    library = "react-icons/cg"
    tag = "CgCornerLeftUp"


class CgCornerRightDown(rx.Component):
    library = "react-icons/cg"
    tag = "CgCornerRightDown"


class CgCornerRightUp(rx.Component):
    library = "react-icons/cg"
    tag = "CgCornerRightUp"


class CgCornerUpLeft(rx.Component):
    library = "react-icons/cg"
    tag = "CgCornerUpLeft"


class CgCornerUpRight(rx.Component):
    library = "react-icons/cg"
    tag = "CgCornerUpRight"


class CgCreditCard(rx.Component):
    library = "react-icons/cg"
    tag = "CgCreditCard"


class CgCrop(rx.Component):
    library = "react-icons/cg"
    tag = "CgCrop"


class CgCross(rx.Component):
    library = "react-icons/cg"
    tag = "CgCross"


class CgCrowdfire(rx.Component):
    library = "react-icons/cg"
    tag = "CgCrowdfire"


class CgCrown(rx.Component):
    library = "react-icons/cg"
    tag = "CgCrown"


class CgDanger(rx.Component):
    library = "react-icons/cg"
    tag = "CgDanger"


class CgDarkMode(rx.Component):
    library = "react-icons/cg"
    tag = "CgDarkMode"


class CgData(rx.Component):
    library = "react-icons/cg"
    tag = "CgData"


class CgDatabase(rx.Component):
    library = "react-icons/cg"
    tag = "CgDatabase"


class CgDebug(rx.Component):
    library = "react-icons/cg"
    tag = "CgDebug"


class CgDesignmodo(rx.Component):
    library = "react-icons/cg"
    tag = "CgDesignmodo"


class CgDesktop(rx.Component):
    library = "react-icons/cg"
    tag = "CgDesktop"


class CgDetailsLess(rx.Component):
    library = "react-icons/cg"
    tag = "CgDetailsLess"


class CgDetailsMore(rx.Component):
    library = "react-icons/cg"
    tag = "CgDetailsMore"


class CgDialpad(rx.Component):
    library = "react-icons/cg"
    tag = "CgDialpad"


class CgDice1(rx.Component):
    library = "react-icons/cg"
    tag = "CgDice1"


class CgDice2(rx.Component):
    library = "react-icons/cg"
    tag = "CgDice2"


class CgDice3(rx.Component):
    library = "react-icons/cg"
    tag = "CgDice3"


class CgDice4(rx.Component):
    library = "react-icons/cg"
    tag = "CgDice4"


class CgDice5(rx.Component):
    library = "react-icons/cg"
    tag = "CgDice5"


class CgDice6(rx.Component):
    library = "react-icons/cg"
    tag = "CgDice6"


class CgDigitalocean(rx.Component):
    library = "react-icons/cg"
    tag = "CgDigitalocean"


class CgDisc(rx.Component):
    library = "react-icons/cg"
    tag = "CgDisc"


class CgDisplayFlex(rx.Component):
    library = "react-icons/cg"
    tag = "CgDisplayFlex"


class CgDisplayFullwidth(rx.Component):
    library = "react-icons/cg"
    tag = "CgDisplayFullwidth"


class CgDisplayGrid(rx.Component):
    library = "react-icons/cg"
    tag = "CgDisplayGrid"


class CgDisplaySpacing(rx.Component):
    library = "react-icons/cg"
    tag = "CgDisplaySpacing"


class CgDistributeHorizontal(rx.Component):
    library = "react-icons/cg"
    tag = "CgDistributeHorizontal"


class CgDistributeVertical(rx.Component):
    library = "react-icons/cg"
    tag = "CgDistributeVertical"


class CgDockBottom(rx.Component):
    library = "react-icons/cg"
    tag = "CgDockBottom"


class CgDockLeft(rx.Component):
    library = "react-icons/cg"
    tag = "CgDockLeft"


class CgDockRight(rx.Component):
    library = "react-icons/cg"
    tag = "CgDockRight"


class CgDockWindow(rx.Component):
    library = "react-icons/cg"
    tag = "CgDockWindow"


class CgDolby(rx.Component):
    library = "react-icons/cg"
    tag = "CgDolby"


class CgDollar(rx.Component):
    library = "react-icons/cg"
    tag = "CgDollar"


class CgDribbble(rx.Component):
    library = "react-icons/cg"
    tag = "CgDribbble"


class CgDrive(rx.Component):
    library = "react-icons/cg"
    tag = "CgDrive"


class CgDropInvert(rx.Component):
    library = "react-icons/cg"
    tag = "CgDropInvert"


class CgDropOpacity(rx.Component):
    library = "react-icons/cg"
    tag = "CgDropOpacity"


class CgDrop(rx.Component):
    library = "react-icons/cg"
    tag = "CgDrop"


class CgDuplicate(rx.Component):
    library = "react-icons/cg"
    tag = "CgDuplicate"


class CgEditBlackPoint(rx.Component):
    library = "react-icons/cg"
    tag = "CgEditBlackPoint"


class CgEditContrast(rx.Component):
    library = "react-icons/cg"
    tag = "CgEditContrast"


class CgEditExposure(rx.Component):
    library = "react-icons/cg"
    tag = "CgEditExposure"


class CgEditFade(rx.Component):
    library = "react-icons/cg"
    tag = "CgEditFade"


class CgEditFlipH(rx.Component):
    library = "react-icons/cg"
    tag = "CgEditFlipH"


class CgEditFlipV(rx.Component):
    library = "react-icons/cg"
    tag = "CgEditFlipV"


class CgEditHighlight(rx.Component):
    library = "react-icons/cg"
    tag = "CgEditHighlight"


class CgEditMarkup(rx.Component):
    library = "react-icons/cg"
    tag = "CgEditMarkup"


class CgEditMask(rx.Component):
    library = "react-icons/cg"
    tag = "CgEditMask"


class CgEditNoise(rx.Component):
    library = "react-icons/cg"
    tag = "CgEditNoise"


class CgEditShadows(rx.Component):
    library = "react-icons/cg"
    tag = "CgEditShadows"


class CgEditStraight(rx.Component):
    library = "react-icons/cg"
    tag = "CgEditStraight"


class CgEditUnmask(rx.Component):
    library = "react-icons/cg"
    tag = "CgEditUnmask"


class CgEject(rx.Component):
    library = "react-icons/cg"
    tag = "CgEject"


class CgEnter(rx.Component):
    library = "react-icons/cg"
    tag = "CgEnter"


class CgErase(rx.Component):
    library = "react-icons/cg"
    tag = "CgErase"


class CgEreader(rx.Component):
    library = "react-icons/cg"
    tag = "CgEreader"


class CgEricsson(rx.Component):
    library = "react-icons/cg"
    tag = "CgEricsson"


class CgEthernet(rx.Component):
    library = "react-icons/cg"
    tag = "CgEthernet"


class CgEuro(rx.Component):
    library = "react-icons/cg"
    tag = "CgEuro"


class CgEventbrite(rx.Component):
    library = "react-icons/cg"
    tag = "CgEventbrite"


class CgExpand(rx.Component):
    library = "react-icons/cg"
    tag = "CgExpand"


class CgExport(rx.Component):
    library = "react-icons/cg"
    tag = "CgExport"


class CgExtensionAdd(rx.Component):
    library = "react-icons/cg"
    tag = "CgExtensionAdd"


class CgExtensionAlt(rx.Component):
    library = "react-icons/cg"
    tag = "CgExtensionAlt"


class CgExtensionRemove(rx.Component):
    library = "react-icons/cg"
    tag = "CgExtensionRemove"


class CgExtension(rx.Component):
    library = "react-icons/cg"
    tag = "CgExtension"


class CgExternal(rx.Component):
    library = "react-icons/cg"
    tag = "CgExternal"


class CgEyeAlt(rx.Component):
    library = "react-icons/cg"
    tag = "CgEyeAlt"


class CgEye(rx.Component):
    library = "react-icons/cg"
    tag = "CgEye"


class CgFacebook(rx.Component):
    library = "react-icons/cg"
    tag = "CgFacebook"


class CgFeed(rx.Component):
    library = "react-icons/cg"
    tag = "CgFeed"


class CgFigma(rx.Component):
    library = "react-icons/cg"
    tag = "CgFigma"


class CgFileAdd(rx.Component):
    library = "react-icons/cg"
    tag = "CgFileAdd"


class CgFileDocument(rx.Component):
    library = "react-icons/cg"
    tag = "CgFileDocument"


class CgFileRemove(rx.Component):
    library = "react-icons/cg"
    tag = "CgFileRemove"


class CgFile(rx.Component):
    library = "react-icons/cg"
    tag = "CgFile"


class CgFilm(rx.Component):
    library = "react-icons/cg"
    tag = "CgFilm"


class CgFilters(rx.Component):
    library = "react-icons/cg"
    tag = "CgFilters"


class CgFlagAlt(rx.Component):
    library = "react-icons/cg"
    tag = "CgFlagAlt"


class CgFlag(rx.Component):
    library = "react-icons/cg"
    tag = "CgFlag"


class CgFolderAdd(rx.Component):
    library = "react-icons/cg"
    tag = "CgFolderAdd"


class CgFolderRemove(rx.Component):
    library = "react-icons/cg"
    tag = "CgFolderRemove"


class CgFolder(rx.Component):
    library = "react-icons/cg"
    tag = "CgFolder"


class CgFontHeight(rx.Component):
    library = "react-icons/cg"
    tag = "CgFontHeight"


class CgFontSpacing(rx.Component):
    library = "react-icons/cg"
    tag = "CgFontSpacing"


class CgFormatBold(rx.Component):
    library = "react-icons/cg"
    tag = "CgFormatBold"


class CgFormatCenter(rx.Component):
    library = "react-icons/cg"
    tag = "CgFormatCenter"


class CgFormatColor(rx.Component):
    library = "react-icons/cg"
    tag = "CgFormatColor"


class CgFormatHeading(rx.Component):
    library = "react-icons/cg"
    tag = "CgFormatHeading"


class CgFormatIndentDecrease(rx.Component):
    library = "react-icons/cg"
    tag = "CgFormatIndentDecrease"


class CgFormatIndentIncrease(rx.Component):
    library = "react-icons/cg"
    tag = "CgFormatIndentIncrease"


class CgFormatItalic(rx.Component):
    library = "react-icons/cg"
    tag = "CgFormatItalic"


class CgFormatJustify(rx.Component):
    library = "react-icons/cg"
    tag = "CgFormatJustify"


class CgFormatLeft(rx.Component):
    library = "react-icons/cg"
    tag = "CgFormatLeft"


class CgFormatLineHeight(rx.Component):
    library = "react-icons/cg"
    tag = "CgFormatLineHeight"


class CgFormatRight(rx.Component):
    library = "react-icons/cg"
    tag = "CgFormatRight"


class CgFormatSeparator(rx.Component):
    library = "react-icons/cg"
    tag = "CgFormatSeparator"


class CgFormatSlash(rx.Component):
    library = "react-icons/cg"
    tag = "CgFormatSlash"


class CgFormatStrike(rx.Component):
    library = "react-icons/cg"
    tag = "CgFormatStrike"


class CgFormatText(rx.Component):
    library = "react-icons/cg"
    tag = "CgFormatText"


class CgFormatUnderline(rx.Component):
    library = "react-icons/cg"
    tag = "CgFormatUnderline"


class CgFormatUppercase(rx.Component):
    library = "react-icons/cg"
    tag = "CgFormatUppercase"


class CgFramer(rx.Component):
    library = "react-icons/cg"
    tag = "CgFramer"


class CgGames(rx.Component):
    library = "react-icons/cg"
    tag = "CgGames"


class CgGenderFemale(rx.Component):
    library = "react-icons/cg"
    tag = "CgGenderFemale"


class CgGenderMale(rx.Component):
    library = "react-icons/cg"
    tag = "CgGenderMale"


class CgGhostCharacter(rx.Component):
    library = "react-icons/cg"
    tag = "CgGhostCharacter"


class CgGhost(rx.Component):
    library = "react-icons/cg"
    tag = "CgGhost"


class CgGift(rx.Component):
    library = "react-icons/cg"
    tag = "CgGift"


class CgGirl(rx.Component):
    library = "react-icons/cg"
    tag = "CgGirl"


class CgGitBranch(rx.Component):
    library = "react-icons/cg"
    tag = "CgGitBranch"


class CgGitCommit(rx.Component):
    library = "react-icons/cg"
    tag = "CgGitCommit"


class CgGitFork(rx.Component):
    library = "react-icons/cg"
    tag = "CgGitFork"


class CgGitPull(rx.Component):
    library = "react-icons/cg"
    tag = "CgGitPull"


class CgGitter(rx.Component):
    library = "react-icons/cg"
    tag = "CgGitter"


class CgGlassAlt(rx.Component):
    library = "react-icons/cg"
    tag = "CgGlassAlt"


class CgGlass(rx.Component):
    library = "react-icons/cg"
    tag = "CgGlass"


class CgGlobeAlt(rx.Component):
    library = "react-icons/cg"
    tag = "CgGlobeAlt"


class CgGlobe(rx.Component):
    library = "react-icons/cg"
    tag = "CgGlobe"


class CgGoogleTasks(rx.Component):
    library = "react-icons/cg"
    tag = "CgGoogleTasks"


class CgGoogle(rx.Component):
    library = "react-icons/cg"
    tag = "CgGoogle"


class CgGym(rx.Component):
    library = "react-icons/cg"
    tag = "CgGym"


class CgHashtag(rx.Component):
    library = "react-icons/cg"
    tag = "CgHashtag"


class CgHeadset(rx.Component):
    library = "react-icons/cg"
    tag = "CgHeadset"


class CgHeart(rx.Component):
    library = "react-icons/cg"
    tag = "CgHeart"


class CgHello(rx.Component):
    library = "react-icons/cg"
    tag = "CgHello"


class CgHomeAlt(rx.Component):
    library = "react-icons/cg"
    tag = "CgHomeAlt"


class CgHomeScreen(rx.Component):
    library = "react-icons/cg"
    tag = "CgHomeScreen"


class CgHome(rx.Component):
    library = "react-icons/cg"
    tag = "CgHome"


class CgIcecream(rx.Component):
    library = "react-icons/cg"
    tag = "CgIcecream"


class CgIfDesign(rx.Component):
    library = "react-icons/cg"
    tag = "CgIfDesign"


class CgImage(rx.Component):
    library = "react-icons/cg"
    tag = "CgImage"


class CgImport(rx.Component):
    library = "react-icons/cg"
    tag = "CgImport"


class CgInbox(rx.Component):
    library = "react-icons/cg"
    tag = "CgInbox"


class CgIndieHackers(rx.Component):
    library = "react-icons/cg"
    tag = "CgIndieHackers"


class CgInfinity(rx.Component):
    library = "react-icons/cg"
    tag = "CgInfinity"


class CgInfo(rx.Component):
    library = "react-icons/cg"
    tag = "CgInfo"


class CgInpicture(rx.Component):
    library = "react-icons/cg"
    tag = "CgInpicture"


class CgInsertAfterO(rx.Component):
    library = "react-icons/cg"
    tag = "CgInsertAfterO"


class CgInsertAfterR(rx.Component):
    library = "react-icons/cg"
    tag = "CgInsertAfterR"


class CgInsertAfter(rx.Component):
    library = "react-icons/cg"
    tag = "CgInsertAfter"


class CgInsertBeforeO(rx.Component):
    library = "react-icons/cg"
    tag = "CgInsertBeforeO"


class CgInsertBeforeR(rx.Component):
    library = "react-icons/cg"
    tag = "CgInsertBeforeR"


class CgInsertBefore(rx.Component):
    library = "react-icons/cg"
    tag = "CgInsertBefore"


class CgInsights(rx.Component):
    library = "react-icons/cg"
    tag = "CgInsights"


class CgInstagram(rx.Component):
    library = "react-icons/cg"
    tag = "CgInstagram"


class CgInternal(rx.Component):
    library = "react-icons/cg"
    tag = "CgInternal"


class CgKey(rx.Component):
    library = "react-icons/cg"
    tag = "CgKey"


class CgKeyboard(rx.Component):
    library = "react-icons/cg"
    tag = "CgKeyboard"


class CgKeyhole(rx.Component):
    library = "react-icons/cg"
    tag = "CgKeyhole"


class CgLaptop(rx.Component):
    library = "react-icons/cg"
    tag = "CgLaptop"


class CgLastpass(rx.Component):
    library = "react-icons/cg"
    tag = "CgLastpass"


class CgLayoutGridSmall(rx.Component):
    library = "react-icons/cg"
    tag = "CgLayoutGridSmall"


class CgLayoutGrid(rx.Component):
    library = "react-icons/cg"
    tag = "CgLayoutGrid"


class CgLayoutList(rx.Component):
    library = "react-icons/cg"
    tag = "CgLayoutList"


class CgLayoutPin(rx.Component):
    library = "react-icons/cg"
    tag = "CgLayoutPin"


class CgLinear(rx.Component):
    library = "react-icons/cg"
    tag = "CgLinear"


class CgLink(rx.Component):
    library = "react-icons/cg"
    tag = "CgLink"


class CgListTree(rx.Component):
    library = "react-icons/cg"
    tag = "CgListTree"


class CgList(rx.Component):
    library = "react-icons/cg"
    tag = "CgList"


class CgLivePhoto(rx.Component):
    library = "react-icons/cg"
    tag = "CgLivePhoto"


class CgLoadbarAlt(rx.Component):
    library = "react-icons/cg"
    tag = "CgLoadbarAlt"


class CgLoadbarDoc(rx.Component):
    library = "react-icons/cg"
    tag = "CgLoadbarDoc"


class CgLoadbarSound(rx.Component):
    library = "react-icons/cg"
    tag = "CgLoadbarSound"


class CgLoadbar(rx.Component):
    library = "react-icons/cg"
    tag = "CgLoadbar"


class CgLockUnlock(rx.Component):
    library = "react-icons/cg"
    tag = "CgLockUnlock"


class CgLock(rx.Component):
    library = "react-icons/cg"
    tag = "CgLock"


class CgLogIn(rx.Component):
    library = "react-icons/cg"
    tag = "CgLogIn"


class CgLogOff(rx.Component):
    library = "react-icons/cg"
    tag = "CgLogOff"


class CgLogOut(rx.Component):
    library = "react-icons/cg"
    tag = "CgLogOut"


class CgLoupe(rx.Component):
    library = "react-icons/cg"
    tag = "CgLoupe"


class CgMagnet(rx.Component):
    library = "react-icons/cg"
    tag = "CgMagnet"


class CgMailForward(rx.Component):
    library = "react-icons/cg"
    tag = "CgMailForward"


class CgMailOpen(rx.Component):
    library = "react-icons/cg"
    tag = "CgMailOpen"


class CgMailReply(rx.Component):
    library = "react-icons/cg"
    tag = "CgMailReply"


class CgMail(rx.Component):
    library = "react-icons/cg"
    tag = "CgMail"


class CgMathDivide(rx.Component):
    library = "react-icons/cg"
    tag = "CgMathDivide"


class CgMathEqual(rx.Component):
    library = "react-icons/cg"
    tag = "CgMathEqual"


class CgMathMinus(rx.Component):
    library = "react-icons/cg"
    tag = "CgMathMinus"


class CgMathPercent(rx.Component):
    library = "react-icons/cg"
    tag = "CgMathPercent"


class CgMathPlus(rx.Component):
    library = "react-icons/cg"
    tag = "CgMathPlus"


class CgMaximizeAlt(rx.Component):
    library = "react-icons/cg"
    tag = "CgMaximizeAlt"


class CgMaximize(rx.Component):
    library = "react-icons/cg"
    tag = "CgMaximize"


class CgMaze(rx.Component):
    library = "react-icons/cg"
    tag = "CgMaze"


class CgMediaLive(rx.Component):
    library = "react-icons/cg"
    tag = "CgMediaLive"


class CgMediaPodcast(rx.Component):
    library = "react-icons/cg"
    tag = "CgMediaPodcast"


class CgMenuBoxed(rx.Component):
    library = "react-icons/cg"
    tag = "CgMenuBoxed"


class CgMenuCake(rx.Component):
    library = "react-icons/cg"
    tag = "CgMenuCake"


class CgMenuCheese(rx.Component):
    library = "react-icons/cg"
    tag = "CgMenuCheese"


class CgMenuGridO(rx.Component):
    library = "react-icons/cg"
    tag = "CgMenuGridO"


class CgMenuGridR(rx.Component):
    library = "react-icons/cg"
    tag = "CgMenuGridR"


class CgMenuHotdog(rx.Component):
    library = "react-icons/cg"
    tag = "CgMenuHotdog"


class CgMenuLeftAlt(rx.Component):
    library = "react-icons/cg"
    tag = "CgMenuLeftAlt"


class CgMenuLeft(rx.Component):
    library = "react-icons/cg"
    tag = "CgMenuLeft"


class CgMenuMotion(rx.Component):
    library = "react-icons/cg"
    tag = "CgMenuMotion"


class CgMenuOreos(rx.Component):
    library = "react-icons/cg"
    tag = "CgMenuOreos"


class CgMenuRightAlt(rx.Component):
    library = "react-icons/cg"
    tag = "CgMenuRightAlt"


class CgMenuRight(rx.Component):
    library = "react-icons/cg"
    tag = "CgMenuRight"


class CgMenuRound(rx.Component):
    library = "react-icons/cg"
    tag = "CgMenuRound"


class CgMenu(rx.Component):
    library = "react-icons/cg"
    tag = "CgMenu"


class CgMergeHorizontal(rx.Component):
    library = "react-icons/cg"
    tag = "CgMergeHorizontal"


class CgMergeVertical(rx.Component):
    library = "react-icons/cg"
    tag = "CgMergeVertical"


class CgMic(rx.Component):
    library = "react-icons/cg"
    tag = "CgMic"


class CgMicrobit(rx.Component):
    library = "react-icons/cg"
    tag = "CgMicrobit"


class CgMicrosoft(rx.Component):
    library = "react-icons/cg"
    tag = "CgMicrosoft"


class CgMiniPlayer(rx.Component):
    library = "react-icons/cg"
    tag = "CgMiniPlayer"


class CgMinimizeAlt(rx.Component):
    library = "react-icons/cg"
    tag = "CgMinimizeAlt"


class CgMinimize(rx.Component):
    library = "react-icons/cg"
    tag = "CgMinimize"


class CgModem(rx.Component):
    library = "react-icons/cg"
    tag = "CgModem"


class CgMonday(rx.Component):
    library = "react-icons/cg"
    tag = "CgMonday"


class CgMoon(rx.Component):
    library = "react-icons/cg"
    tag = "CgMoon"


class CgMoreAlt(rx.Component):
    library = "react-icons/cg"
    tag = "CgMoreAlt"


class CgMoreO(rx.Component):
    library = "react-icons/cg"
    tag = "CgMoreO"


class CgMoreR(rx.Component):
    library = "react-icons/cg"
    tag = "CgMoreR"


class CgMoreVerticalAlt(rx.Component):
    library = "react-icons/cg"
    tag = "CgMoreVerticalAlt"


class CgMoreVerticalO(rx.Component):
    library = "react-icons/cg"
    tag = "CgMoreVerticalO"


class CgMoreVerticalR(rx.Component):
    library = "react-icons/cg"
    tag = "CgMoreVerticalR"


class CgMoreVertical(rx.Component):
    library = "react-icons/cg"
    tag = "CgMoreVertical"


class CgMore(rx.Component):
    library = "react-icons/cg"
    tag = "CgMore"


class CgMouse(rx.Component):
    library = "react-icons/cg"
    tag = "CgMouse"


class CgMoveDown(rx.Component):
    library = "react-icons/cg"
    tag = "CgMoveDown"


class CgMoveLeft(rx.Component):
    library = "react-icons/cg"
    tag = "CgMoveLeft"


class CgMoveRight(rx.Component):
    library = "react-icons/cg"
    tag = "CgMoveRight"


class CgMoveTask(rx.Component):
    library = "react-icons/cg"
    tag = "CgMoveTask"


class CgMoveUp(rx.Component):
    library = "react-icons/cg"
    tag = "CgMoveUp"


class CgMusicNote(rx.Component):
    library = "react-icons/cg"
    tag = "CgMusicNote"


class CgMusicSpeaker(rx.Component):
    library = "react-icons/cg"
    tag = "CgMusicSpeaker"


class CgMusic(rx.Component):
    library = "react-icons/cg"
    tag = "CgMusic"


class CgNametag(rx.Component):
    library = "react-icons/cg"
    tag = "CgNametag"


class CgNotes(rx.Component):
    library = "react-icons/cg"
    tag = "CgNotes"


class CgNotifications(rx.Component):
    library = "react-icons/cg"
    tag = "CgNotifications"


class CgNpm(rx.Component):
    library = "react-icons/cg"
    tag = "CgNpm"


class CgOculus(rx.Component):
    library = "react-icons/cg"
    tag = "CgOculus"


class CgOpenCollective(rx.Component):
    library = "react-icons/cg"
    tag = "CgOpenCollective"


class CgOptions(rx.Component):
    library = "react-icons/cg"
    tag = "CgOptions"


class CgOrganisation(rx.Component):
    library = "react-icons/cg"
    tag = "CgOrganisation"


class CgOverflow(rx.Component):
    library = "react-icons/cg"
    tag = "CgOverflow"


class CgPacman(rx.Component):
    library = "react-icons/cg"
    tag = "CgPacman"


class CgPassword(rx.Component):
    library = "react-icons/cg"
    tag = "CgPassword"


class CgPathBack(rx.Component):
    library = "react-icons/cg"
    tag = "CgPathBack"


class CgPathCrop(rx.Component):
    library = "react-icons/cg"
    tag = "CgPathCrop"


class CgPathDivide(rx.Component):
    library = "react-icons/cg"
    tag = "CgPathDivide"


class CgPathExclude(rx.Component):
    library = "react-icons/cg"
    tag = "CgPathExclude"


class CgPathFront(rx.Component):
    library = "react-icons/cg"
    tag = "CgPathFront"


class CgPathIntersect(rx.Component):
    library = "react-icons/cg"
    tag = "CgPathIntersect"


class CgPathOutline(rx.Component):
    library = "react-icons/cg"
    tag = "CgPathOutline"


class CgPathTrim(rx.Component):
    library = "react-icons/cg"
    tag = "CgPathTrim"


class CgPathUnite(rx.Component):
    library = "react-icons/cg"
    tag = "CgPathUnite"


class CgPatreon(rx.Component):
    library = "react-icons/cg"
    tag = "CgPatreon"


class CgPaypal(rx.Component):
    library = "react-icons/cg"
    tag = "CgPaypal"


class CgPen(rx.Component):
    library = "react-icons/cg"
    tag = "CgPen"


class CgPentagonBottomLeft(rx.Component):
    library = "react-icons/cg"
    tag = "CgPentagonBottomLeft"


class CgPentagonBottomRight(rx.Component):
    library = "react-icons/cg"
    tag = "CgPentagonBottomRight"


class CgPentagonDown(rx.Component):
    library = "react-icons/cg"
    tag = "CgPentagonDown"


class CgPentagonLeft(rx.Component):
    library = "react-icons/cg"
    tag = "CgPentagonLeft"


class CgPentagonRight(rx.Component):
    library = "react-icons/cg"
    tag = "CgPentagonRight"


class CgPentagonTopLeft(rx.Component):
    library = "react-icons/cg"
    tag = "CgPentagonTopLeft"


class CgPentagonTopRight(rx.Component):
    library = "react-icons/cg"
    tag = "CgPentagonTopRight"


class CgPentagonUp(rx.Component):
    library = "react-icons/cg"
    tag = "CgPentagonUp"


class CgPerformance(rx.Component):
    library = "react-icons/cg"
    tag = "CgPerformance"


class CgPexels(rx.Component):
    library = "react-icons/cg"
    tag = "CgPexels"


class CgPhone(rx.Component):
    library = "react-icons/cg"
    tag = "CgPhone"


class CgPhotoscan(rx.Component):
    library = "react-icons/cg"
    tag = "CgPhotoscan"


class CgPiano(rx.Component):
    library = "react-icons/cg"
    tag = "CgPiano"


class CgPill(rx.Component):
    library = "react-icons/cg"
    tag = "CgPill"


class CgPinAlt(rx.Component):
    library = "react-icons/cg"
    tag = "CgPinAlt"


class CgPinBottom(rx.Component):
    library = "react-icons/cg"
    tag = "CgPinBottom"


class CgPinTop(rx.Component):
    library = "react-icons/cg"
    tag = "CgPinTop"


class CgPin(rx.Component):
    library = "react-icons/cg"
    tag = "CgPin"


class CgPlayBackwards(rx.Component):
    library = "react-icons/cg"
    tag = "CgPlayBackwards"


class CgPlayButtonO(rx.Component):
    library = "react-icons/cg"
    tag = "CgPlayButtonO"


class CgPlayButtonR(rx.Component):
    library = "react-icons/cg"
    tag = "CgPlayButtonR"


class CgPlayButton(rx.Component):
    library = "react-icons/cg"
    tag = "CgPlayButton"


class CgPlayForwards(rx.Component):
    library = "react-icons/cg"
    tag = "CgPlayForwards"


class CgPlayListAdd(rx.Component):
    library = "react-icons/cg"
    tag = "CgPlayListAdd"


class CgPlayListCheck(rx.Component):
    library = "react-icons/cg"
    tag = "CgPlayListCheck"


class CgPlayListRemove(rx.Component):
    library = "react-icons/cg"
    tag = "CgPlayListRemove"


class CgPlayListSearch(rx.Component):
    library = "react-icons/cg"
    tag = "CgPlayListSearch"


class CgPlayList(rx.Component):
    library = "react-icons/cg"
    tag = "CgPlayList"


class CgPlayPauseO(rx.Component):
    library = "react-icons/cg"
    tag = "CgPlayPauseO"


class CgPlayPauseR(rx.Component):
    library = "react-icons/cg"
    tag = "CgPlayPauseR"


class CgPlayPause(rx.Component):
    library = "react-icons/cg"
    tag = "CgPlayPause"


class CgPlayStopO(rx.Component):
    library = "react-icons/cg"
    tag = "CgPlayStopO"


class CgPlayStopR(rx.Component):
    library = "react-icons/cg"
    tag = "CgPlayStopR"


class CgPlayStop(rx.Component):
    library = "react-icons/cg"
    tag = "CgPlayStop"


class CgPlayTrackNextO(rx.Component):
    library = "react-icons/cg"
    tag = "CgPlayTrackNextO"


class CgPlayTrackNextR(rx.Component):
    library = "react-icons/cg"
    tag = "CgPlayTrackNextR"


class CgPlayTrackNext(rx.Component):
    library = "react-icons/cg"
    tag = "CgPlayTrackNext"


class CgPlayTrackPrevO(rx.Component):
    library = "react-icons/cg"
    tag = "CgPlayTrackPrevO"


class CgPlayTrackPrevR(rx.Component):
    library = "react-icons/cg"
    tag = "CgPlayTrackPrevR"


class CgPlayTrackPrev(rx.Component):
    library = "react-icons/cg"
    tag = "CgPlayTrackPrev"


class CgPlug(rx.Component):
    library = "react-icons/cg"
    tag = "CgPlug"


class CgPocket(rx.Component):
    library = "react-icons/cg"
    tag = "CgPocket"


class CgPokemon(rx.Component):
    library = "react-icons/cg"
    tag = "CgPokemon"


class CgPolaroid(rx.Component):
    library = "react-icons/cg"
    tag = "CgPolaroid"


class CgPoll(rx.Component):
    library = "react-icons/cg"
    tag = "CgPoll"


class CgPresentation(rx.Component):
    library = "react-icons/cg"
    tag = "CgPresentation"


class CgPrinter(rx.Component):
    library = "react-icons/cg"
    tag = "CgPrinter"


class CgProductHunt(rx.Component):
    library = "react-icons/cg"
    tag = "CgProductHunt"


class CgProfile(rx.Component):
    library = "react-icons/cg"
    tag = "CgProfile"


class CgPullClear(rx.Component):
    library = "react-icons/cg"
    tag = "CgPullClear"


class CgPushChevronDownO(rx.Component):
    library = "react-icons/cg"
    tag = "CgPushChevronDownO"


class CgPushChevronDownR(rx.Component):
    library = "react-icons/cg"
    tag = "CgPushChevronDownR"


class CgPushChevronDown(rx.Component):
    library = "react-icons/cg"
    tag = "CgPushChevronDown"


class CgPushChevronLeftO(rx.Component):
    library = "react-icons/cg"
    tag = "CgPushChevronLeftO"


class CgPushChevronLeftR(rx.Component):
    library = "react-icons/cg"
    tag = "CgPushChevronLeftR"


class CgPushChevronLeft(rx.Component):
    library = "react-icons/cg"
    tag = "CgPushChevronLeft"


class CgPushChevronRightO(rx.Component):
    library = "react-icons/cg"
    tag = "CgPushChevronRightO"


class CgPushChevronRightR(rx.Component):
    library = "react-icons/cg"
    tag = "CgPushChevronRightR"


class CgPushChevronRight(rx.Component):
    library = "react-icons/cg"
    tag = "CgPushChevronRight"


class CgPushChevronUpO(rx.Component):
    library = "react-icons/cg"
    tag = "CgPushChevronUpO"


class CgPushChevronUpR(rx.Component):
    library = "react-icons/cg"
    tag = "CgPushChevronUpR"


class CgPushChevronUp(rx.Component):
    library = "react-icons/cg"
    tag = "CgPushChevronUp"


class CgPushDown(rx.Component):
    library = "react-icons/cg"
    tag = "CgPushDown"


class CgPushLeft(rx.Component):
    library = "react-icons/cg"
    tag = "CgPushLeft"


class CgPushRight(rx.Component):
    library = "react-icons/cg"
    tag = "CgPushRight"


class CgPushUp(rx.Component):
    library = "react-icons/cg"
    tag = "CgPushUp"


class CgQr(rx.Component):
    library = "react-icons/cg"
    tag = "CgQr"


class CgQuoteO(rx.Component):
    library = "react-icons/cg"
    tag = "CgQuoteO"


class CgQuote(rx.Component):
    library = "react-icons/cg"
    tag = "CgQuote"


class CgRadioCheck(rx.Component):
    library = "react-icons/cg"
    tag = "CgRadioCheck"


class CgRadioChecked(rx.Component):
    library = "react-icons/cg"
    tag = "CgRadioChecked"


class CgRatio(rx.Component):
    library = "react-icons/cg"
    tag = "CgRatio"


class CgRead(rx.Component):
    library = "react-icons/cg"
    tag = "CgRead"


class CgReadme(rx.Component):
    library = "react-icons/cg"
    tag = "CgReadme"


class CgRecord(rx.Component):
    library = "react-icons/cg"
    tag = "CgRecord"


class CgRedo(rx.Component):
    library = "react-icons/cg"
    tag = "CgRedo"


class CgRemote(rx.Component):
    library = "react-icons/cg"
    tag = "CgRemote"


class CgRemoveR(rx.Component):
    library = "react-icons/cg"
    tag = "CgRemoveR"


class CgRemove(rx.Component):
    library = "react-icons/cg"
    tag = "CgRemove"


class CgRename(rx.Component):
    library = "react-icons/cg"
    tag = "CgRename"


class CgReorder(rx.Component):
    library = "react-icons/cg"
    tag = "CgReorder"


class CgRepeat(rx.Component):
    library = "react-icons/cg"
    tag = "CgRepeat"


class CgRing(rx.Component):
    library = "react-icons/cg"
    tag = "CgRing"


class CgRowFirst(rx.Component):
    library = "react-icons/cg"
    tag = "CgRowFirst"


class CgRowLast(rx.Component):
    library = "react-icons/cg"
    tag = "CgRowLast"


class CgRuler(rx.Component):
    library = "react-icons/cg"
    tag = "CgRuler"


class CgSandClock(rx.Component):
    library = "react-icons/cg"
    tag = "CgSandClock"


class CgScan(rx.Component):
    library = "react-icons/cg"
    tag = "CgScan"


class CgScreenMirror(rx.Component):
    library = "react-icons/cg"
    tag = "CgScreenMirror"


class CgScreenShot(rx.Component):
    library = "react-icons/cg"
    tag = "CgScreenShot"


class CgScreenWide(rx.Component):
    library = "react-icons/cg"
    tag = "CgScreenWide"


class CgScreen(rx.Component):
    library = "react-icons/cg"
    tag = "CgScreen"


class CgScrollH(rx.Component):
    library = "react-icons/cg"
    tag = "CgScrollH"


class CgScrollV(rx.Component):
    library = "react-icons/cg"
    tag = "CgScrollV"


class CgSearchFound(rx.Component):
    library = "react-icons/cg"
    tag = "CgSearchFound"


class CgSearchLoading(rx.Component):
    library = "react-icons/cg"
    tag = "CgSearchLoading"


class CgSearch(rx.Component):
    library = "react-icons/cg"
    tag = "CgSearch"


class CgSelectO(rx.Component):
    library = "react-icons/cg"
    tag = "CgSelectO"


class CgSelectR(rx.Component):
    library = "react-icons/cg"
    tag = "CgSelectR"


class CgSelect(rx.Component):
    library = "react-icons/cg"
    tag = "CgSelect"


class CgServer(rx.Component):
    library = "react-icons/cg"
    tag = "CgServer"


class CgServerless(rx.Component):
    library = "react-icons/cg"
    tag = "CgServerless"


class CgShapeCircle(rx.Component):
    library = "react-icons/cg"
    tag = "CgShapeCircle"


class CgShapeHalfCircle(rx.Component):
    library = "react-icons/cg"
    tag = "CgShapeHalfCircle"


class CgShapeHexagon(rx.Component):
    library = "react-icons/cg"
    tag = "CgShapeHexagon"


class CgShapeRhombus(rx.Component):
    library = "react-icons/cg"
    tag = "CgShapeRhombus"


class CgShapeSquare(rx.Component):
    library = "react-icons/cg"
    tag = "CgShapeSquare"


class CgShapeTriangle(rx.Component):
    library = "react-icons/cg"
    tag = "CgShapeTriangle"


class CgShapeZigzag(rx.Component):
    library = "react-icons/cg"
    tag = "CgShapeZigzag"


class CgShare(rx.Component):
    library = "react-icons/cg"
    tag = "CgShare"


class CgShield(rx.Component):
    library = "react-icons/cg"
    tag = "CgShield"


class CgShoppingBag(rx.Component):
    library = "react-icons/cg"
    tag = "CgShoppingBag"


class CgShoppingCart(rx.Component):
    library = "react-icons/cg"
    tag = "CgShoppingCart"


class CgShortcut(rx.Component):
    library = "react-icons/cg"
    tag = "CgShortcut"


class CgShutterstock(rx.Component):
    library = "react-icons/cg"
    tag = "CgShutterstock"


class CgSidebarOpen(rx.Component):
    library = "react-icons/cg"
    tag = "CgSidebarOpen"


class CgSidebarRight(rx.Component):
    library = "react-icons/cg"
    tag = "CgSidebarRight"


class CgSidebar(rx.Component):
    library = "react-icons/cg"
    tag = "CgSidebar"


class CgSignal(rx.Component):
    library = "react-icons/cg"
    tag = "CgSignal"


class CgSize(rx.Component):
    library = "react-icons/cg"
    tag = "CgSize"


class CgSketch(rx.Component):
    library = "react-icons/cg"
    tag = "CgSketch"


class CgSlack(rx.Component):
    library = "react-icons/cg"
    tag = "CgSlack"


class CgSleep(rx.Component):
    library = "react-icons/cg"
    tag = "CgSleep"


class CgSmartHomeBoiler(rx.Component):
    library = "react-icons/cg"
    tag = "CgSmartHomeBoiler"


class CgSmartHomeCooker(rx.Component):
    library = "react-icons/cg"
    tag = "CgSmartHomeCooker"


class CgSmartHomeHeat(rx.Component):
    library = "react-icons/cg"
    tag = "CgSmartHomeHeat"


class CgSmartHomeLight(rx.Component):
    library = "react-icons/cg"
    tag = "CgSmartHomeLight"


class CgSmartHomeRefrigerator(rx.Component):
    library = "react-icons/cg"
    tag = "CgSmartHomeRefrigerator"


class CgSmartHomeWashMachine(rx.Component):
    library = "react-icons/cg"
    tag = "CgSmartHomeWashMachine"


class CgSmartphoneChip(rx.Component):
    library = "react-icons/cg"
    tag = "CgSmartphoneChip"


class CgSmartphoneRam(rx.Component):
    library = "react-icons/cg"
    tag = "CgSmartphoneRam"


class CgSmartphoneShake(rx.Component):
    library = "react-icons/cg"
    tag = "CgSmartphoneShake"


class CgSmartphone(rx.Component):
    library = "react-icons/cg"
    tag = "CgSmartphone"


class CgSmileMouthOpen(rx.Component):
    library = "react-icons/cg"
    tag = "CgSmileMouthOpen"


class CgSmileNeutral(rx.Component):
    library = "react-icons/cg"
    tag = "CgSmileNeutral"


class CgSmileNoMouth(rx.Component):
    library = "react-icons/cg"
    tag = "CgSmileNoMouth"


class CgSmileNone(rx.Component):
    library = "react-icons/cg"
    tag = "CgSmileNone"


class CgSmileSad(rx.Component):
    library = "react-icons/cg"
    tag = "CgSmileSad"


class CgSmileUpside(rx.Component):
    library = "react-icons/cg"
    tag = "CgSmileUpside"


class CgSmile(rx.Component):
    library = "react-icons/cg"
    tag = "CgSmile"


class CgSoftwareDownload(rx.Component):
    library = "react-icons/cg"
    tag = "CgSoftwareDownload"


class CgSoftwareUpload(rx.Component):
    library = "react-icons/cg"
    tag = "CgSoftwareUpload"


class CgSortAz(rx.Component):
    library = "react-icons/cg"
    tag = "CgSortAz"


class CgSortZa(rx.Component):
    library = "react-icons/cg"
    tag = "CgSortZa"


class CgSpaceBetweenV(rx.Component):
    library = "react-icons/cg"
    tag = "CgSpaceBetweenV"


class CgSpaceBetween(rx.Component):
    library = "react-icons/cg"
    tag = "CgSpaceBetween"


class CgSpectrum(rx.Component):
    library = "react-icons/cg"
    tag = "CgSpectrum"


class CgSpinnerAlt(rx.Component):
    library = "react-icons/cg"
    tag = "CgSpinnerAlt"


class CgSpinnerTwoAlt(rx.Component):
    library = "react-icons/cg"
    tag = "CgSpinnerTwoAlt"


class CgSpinnerTwo(rx.Component):
    library = "react-icons/cg"
    tag = "CgSpinnerTwo"


class CgSpinner(rx.Component):
    library = "react-icons/cg"
    tag = "CgSpinner"


class CgSquare(rx.Component):
    library = "react-icons/cg"
    tag = "CgSquare"


class CgStack(rx.Component):
    library = "react-icons/cg"
    tag = "CgStack"


class CgStark(rx.Component):
    library = "react-icons/cg"
    tag = "CgStark"


class CgStopwatch(rx.Component):
    library = "react-icons/cg"
    tag = "CgStopwatch"


class CgStories(rx.Component):
    library = "react-icons/cg"
    tag = "CgStories"


class CgStudio(rx.Component):
    library = "react-icons/cg"
    tag = "CgStudio"


class CgStyle(rx.Component):
    library = "react-icons/cg"
    tag = "CgStyle"


class CgSun(rx.Component):
    library = "react-icons/cg"
    tag = "CgSun"


class CgSupport(rx.Component):
    library = "react-icons/cg"
    tag = "CgSupport"


class CgSwapVertical(rx.Component):
    library = "react-icons/cg"
    tag = "CgSwapVertical"


class CgSwap(rx.Component):
    library = "react-icons/cg"
    tag = "CgSwap"


class CgSweden(rx.Component):
    library = "react-icons/cg"
    tag = "CgSweden"


class CgSwiss(rx.Component):
    library = "react-icons/cg"
    tag = "CgSwiss"


class CgSync(rx.Component):
    library = "react-icons/cg"
    tag = "CgSync"


class CgTab(rx.Component):
    library = "react-icons/cg"
    tag = "CgTab"


class CgTag(rx.Component):
    library = "react-icons/cg"
    tag = "CgTag"


class CgTally(rx.Component):
    library = "react-icons/cg"
    tag = "CgTally"


class CgTapDouble(rx.Component):
    library = "react-icons/cg"
    tag = "CgTapDouble"


class CgTapSingle(rx.Component):
    library = "react-icons/cg"
    tag = "CgTapSingle"


class CgTemplate(rx.Component):
    library = "react-icons/cg"
    tag = "CgTemplate"


class CgTennis(rx.Component):
    library = "react-icons/cg"
    tag = "CgTennis"


class CgTerminal(rx.Component):
    library = "react-icons/cg"
    tag = "CgTerminal"


class CgTerrain(rx.Component):
    library = "react-icons/cg"
    tag = "CgTerrain"


class CgThermometer(rx.Component):
    library = "react-icons/cg"
    tag = "CgThermometer"


class CgThermostat(rx.Component):
    library = "react-icons/cg"
    tag = "CgThermostat"


class CgTikcode(rx.Component):
    library = "react-icons/cg"
    tag = "CgTikcode"


class CgTime(rx.Component):
    library = "react-icons/cg"
    tag = "CgTime"


class CgTimelapse(rx.Component):
    library = "react-icons/cg"
    tag = "CgTimelapse"


class CgTimer(rx.Component):
    library = "react-icons/cg"
    tag = "CgTimer"


class CgToday(rx.Component):
    library = "react-icons/cg"
    tag = "CgToday"


class CgToggleOff(rx.Component):
    library = "react-icons/cg"
    tag = "CgToggleOff"


class CgToggleOn(rx.Component):
    library = "react-icons/cg"
    tag = "CgToggleOn"


class CgToggleSquareOff(rx.Component):
    library = "react-icons/cg"
    tag = "CgToggleSquareOff"


class CgToggleSquare(rx.Component):
    library = "react-icons/cg"
    tag = "CgToggleSquare"


class CgToolbarBottom(rx.Component):
    library = "react-icons/cg"
    tag = "CgToolbarBottom"


class CgToolbarLeft(rx.Component):
    library = "react-icons/cg"
    tag = "CgToolbarLeft"


class CgToolbarRight(rx.Component):
    library = "react-icons/cg"
    tag = "CgToolbarRight"


class CgToolbarTop(rx.Component):
    library = "react-icons/cg"
    tag = "CgToolbarTop"


class CgToolbox(rx.Component):
    library = "react-icons/cg"
    tag = "CgToolbox"


class CgTouchpad(rx.Component):
    library = "react-icons/cg"
    tag = "CgTouchpad"


class CgTrack(rx.Component):
    library = "react-icons/cg"
    tag = "CgTrack"


class CgTranscript(rx.Component):
    library = "react-icons/cg"
    tag = "CgTranscript"


class CgTrashEmpty(rx.Component):
    library = "react-icons/cg"
    tag = "CgTrashEmpty"


class CgTrash(rx.Component):
    library = "react-icons/cg"
    tag = "CgTrash"


class CgTree(rx.Component):
    library = "react-icons/cg"
    tag = "CgTree"


class CgTrees(rx.Component):
    library = "react-icons/cg"
    tag = "CgTrees"


class CgTrello(rx.Component):
    library = "react-icons/cg"
    tag = "CgTrello"


class CgTrendingDown(rx.Component):
    library = "react-icons/cg"
    tag = "CgTrendingDown"


class CgTrending(rx.Component):
    library = "react-icons/cg"
    tag = "CgTrending"


class CgTrophy(rx.Component):
    library = "react-icons/cg"
    tag = "CgTrophy"


class CgTv(rx.Component):
    library = "react-icons/cg"
    tag = "CgTv"


class CgTwilio(rx.Component):
    library = "react-icons/cg"
    tag = "CgTwilio"


class CgTwitter(rx.Component):
    library = "react-icons/cg"
    tag = "CgTwitter"


class CgUiKit(rx.Component):
    library = "react-icons/cg"
    tag = "CgUiKit"


class CgUmbrella(rx.Component):
    library = "react-icons/cg"
    tag = "CgUmbrella"


class CgUnavailable(rx.Component):
    library = "react-icons/cg"
    tag = "CgUnavailable"


class CgUnblock(rx.Component):
    library = "react-icons/cg"
    tag = "CgUnblock"


class CgUndo(rx.Component):
    library = "react-icons/cg"
    tag = "CgUndo"


class CgUnfold(rx.Component):
    library = "react-icons/cg"
    tag = "CgUnfold"


class CgUnsplash(rx.Component):
    library = "react-icons/cg"
    tag = "CgUnsplash"


class CgUsbC(rx.Component):
    library = "react-icons/cg"
    tag = "CgUsbC"


class CgUsb(rx.Component):
    library = "react-icons/cg"
    tag = "CgUsb"


class CgUserAdd(rx.Component):
    library = "react-icons/cg"
    tag = "CgUserAdd"


class CgUserList(rx.Component):
    library = "react-icons/cg"
    tag = "CgUserList"


class CgUserRemove(rx.Component):
    library = "react-icons/cg"
    tag = "CgUserRemove"


class CgUser(rx.Component):
    library = "react-icons/cg"
    tag = "CgUser"


class CgUserlane(rx.Component):
    library = "react-icons/cg"
    tag = "CgUserlane"


class CgViewCols(rx.Component):
    library = "react-icons/cg"
    tag = "CgViewCols"


class CgViewComfortable(rx.Component):
    library = "react-icons/cg"
    tag = "CgViewComfortable"


class CgViewDay(rx.Component):
    library = "react-icons/cg"
    tag = "CgViewDay"


class CgViewGrid(rx.Component):
    library = "react-icons/cg"
    tag = "CgViewGrid"


class CgViewList(rx.Component):
    library = "react-icons/cg"
    tag = "CgViewList"


class CgViewMonth(rx.Component):
    library = "react-icons/cg"
    tag = "CgViewMonth"


class CgViewSplit(rx.Component):
    library = "react-icons/cg"
    tag = "CgViewSplit"


class CgVinyl(rx.Component):
    library = "react-icons/cg"
    tag = "CgVinyl"


class CgVoicemailO(rx.Component):
    library = "react-icons/cg"
    tag = "CgVoicemailO"


class CgVoicemailR(rx.Component):
    library = "react-icons/cg"
    tag = "CgVoicemailR"


class CgVoicemail(rx.Component):
    library = "react-icons/cg"
    tag = "CgVoicemail"


class CgVolume(rx.Component):
    library = "react-icons/cg"
    tag = "CgVolume"


class CgWebcam(rx.Component):
    library = "react-icons/cg"
    tag = "CgWebcam"


class CgWebsite(rx.Component):
    library = "react-icons/cg"
    tag = "CgWebsite"


class CgWindows(rx.Component):
    library = "react-icons/cg"
    tag = "CgWindows"


class CgWorkAlt(rx.Component):
    library = "react-icons/cg"
    tag = "CgWorkAlt"


class CgYinyang(rx.Component):
    library = "react-icons/cg"
    tag = "CgYinyang"


class CgYoutube(rx.Component):
    library = "react-icons/cg"
    tag = "CgYoutube"


class CgZeit(rx.Component):
    library = "react-icons/cg"
    tag = "CgZeit"


class CgZoomIn(rx.Component):
    library = "react-icons/cg"
    tag = "CgZoomIn"


class CgZoomOut(rx.Component):
    library = "react-icons/cg"
    tag = "CgZoomOut"





import reflex as rx

class WiAlien(rx.Component):
    library = "react-icons/wi"
    tag = "WiAlien"


class WiBarometer(rx.Component):
    library = "react-icons/wi"
    tag = "WiBarometer"


class WiCelsius(rx.Component):
    library = "react-icons/wi"
    tag = "WiCelsius"


class WiCloudDown(rx.Component):
    library = "react-icons/wi"
    tag = "WiCloudDown"


class WiCloudRefresh(rx.Component):
    library = "react-icons/wi"
    tag = "WiCloudRefresh"


class WiCloudUp(rx.Component):
    library = "react-icons/wi"
    tag = "WiCloudUp"


class WiCloud(rx.Component):
    library = "react-icons/wi"
    tag = "WiCloud"


class WiCloudyGusts(rx.Component):
    library = "react-icons/wi"
    tag = "WiCloudyGusts"


class WiCloudyWindy(rx.Component):
    library = "react-icons/wi"
    tag = "WiCloudyWindy"


class WiCloudy(rx.Component):
    library = "react-icons/wi"
    tag = "WiCloudy"


class WiDayCloudyGusts(rx.Component):
    library = "react-icons/wi"
    tag = "WiDayCloudyGusts"


class WiDayCloudyHigh(rx.Component):
    library = "react-icons/wi"
    tag = "WiDayCloudyHigh"


class WiDayCloudyWindy(rx.Component):
    library = "react-icons/wi"
    tag = "WiDayCloudyWindy"


class WiDayCloudy(rx.Component):
    library = "react-icons/wi"
    tag = "WiDayCloudy"


class WiDayFog(rx.Component):
    library = "react-icons/wi"
    tag = "WiDayFog"


class WiDayHail(rx.Component):
    library = "react-icons/wi"
    tag = "WiDayHail"


class WiDayHaze(rx.Component):
    library = "react-icons/wi"
    tag = "WiDayHaze"


class WiDayLightWind(rx.Component):
    library = "react-icons/wi"
    tag = "WiDayLightWind"


class WiDayLightning(rx.Component):
    library = "react-icons/wi"
    tag = "WiDayLightning"


class WiDayRainMix(rx.Component):
    library = "react-icons/wi"
    tag = "WiDayRainMix"


class WiDayRainWind(rx.Component):
    library = "react-icons/wi"
    tag = "WiDayRainWind"


class WiDayRain(rx.Component):
    library = "react-icons/wi"
    tag = "WiDayRain"


class WiDayShowers(rx.Component):
    library = "react-icons/wi"
    tag = "WiDayShowers"


class WiDaySleetStorm(rx.Component):
    library = "react-icons/wi"
    tag = "WiDaySleetStorm"


class WiDaySleet(rx.Component):
    library = "react-icons/wi"
    tag = "WiDaySleet"


class WiDaySnowThunderstorm(rx.Component):
    library = "react-icons/wi"
    tag = "WiDaySnowThunderstorm"


class WiDaySnowWind(rx.Component):
    library = "react-icons/wi"
    tag = "WiDaySnowWind"


class WiDaySnow(rx.Component):
    library = "react-icons/wi"
    tag = "WiDaySnow"


class WiDaySprinkle(rx.Component):
    library = "react-icons/wi"
    tag = "WiDaySprinkle"


class WiDayStormShowers(rx.Component):
    library = "react-icons/wi"
    tag = "WiDayStormShowers"


class WiDaySunnyOvercast(rx.Component):
    library = "react-icons/wi"
    tag = "WiDaySunnyOvercast"


class WiDaySunny(rx.Component):
    library = "react-icons/wi"
    tag = "WiDaySunny"


class WiDayThunderstorm(rx.Component):
    library = "react-icons/wi"
    tag = "WiDayThunderstorm"


class WiDayWindy(rx.Component):
    library = "react-icons/wi"
    tag = "WiDayWindy"


class WiDegrees(rx.Component):
    library = "react-icons/wi"
    tag = "WiDegrees"


class WiDirectionDownLeft(rx.Component):
    library = "react-icons/wi"
    tag = "WiDirectionDownLeft"


class WiDirectionDownRight(rx.Component):
    library = "react-icons/wi"
    tag = "WiDirectionDownRight"


class WiDirectionDown(rx.Component):
    library = "react-icons/wi"
    tag = "WiDirectionDown"


class WiDirectionLeft(rx.Component):
    library = "react-icons/wi"
    tag = "WiDirectionLeft"


class WiDirectionRight(rx.Component):
    library = "react-icons/wi"
    tag = "WiDirectionRight"


class WiDirectionUpLeft(rx.Component):
    library = "react-icons/wi"
    tag = "WiDirectionUpLeft"


class WiDirectionUpRight(rx.Component):
    library = "react-icons/wi"
    tag = "WiDirectionUpRight"


class WiDirectionUp(rx.Component):
    library = "react-icons/wi"
    tag = "WiDirectionUp"


class WiDust(rx.Component):
    library = "react-icons/wi"
    tag = "WiDust"


class WiEarthquake(rx.Component):
    library = "react-icons/wi"
    tag = "WiEarthquake"


class WiFahrenheit(rx.Component):
    library = "react-icons/wi"
    tag = "WiFahrenheit"


class WiFire(rx.Component):
    library = "react-icons/wi"
    tag = "WiFire"


class WiFlood(rx.Component):
    library = "react-icons/wi"
    tag = "WiFlood"


class WiFog(rx.Component):
    library = "react-icons/wi"
    tag = "WiFog"


class WiGaleWarning(rx.Component):
    library = "react-icons/wi"
    tag = "WiGaleWarning"


class WiHail(rx.Component):
    library = "react-icons/wi"
    tag = "WiHail"


class WiHorizonAlt(rx.Component):
    library = "react-icons/wi"
    tag = "WiHorizonAlt"


class WiHorizon(rx.Component):
    library = "react-icons/wi"
    tag = "WiHorizon"


class WiHot(rx.Component):
    library = "react-icons/wi"
    tag = "WiHot"


class WiHumidity(rx.Component):
    library = "react-icons/wi"
    tag = "WiHumidity"


class WiHurricaneWarning(rx.Component):
    library = "react-icons/wi"
    tag = "WiHurricaneWarning"


class WiHurricane(rx.Component):
    library = "react-icons/wi"
    tag = "WiHurricane"


class WiLightning(rx.Component):
    library = "react-icons/wi"
    tag = "WiLightning"


class WiLunarEclipse(rx.Component):
    library = "react-icons/wi"
    tag = "WiLunarEclipse"


class WiMeteor(rx.Component):
    library = "react-icons/wi"
    tag = "WiMeteor"


class WiMoonAltFirstQuarter(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonAltFirstQuarter"


class WiMoonAltFull(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonAltFull"


class WiMoonAltNew(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonAltNew"


class WiMoonAltThirdQuarter(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonAltThirdQuarter"


class WiMoonAltWaningCrescent1(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonAltWaningCrescent1"


class WiMoonAltWaningCrescent2(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonAltWaningCrescent2"


class WiMoonAltWaningCrescent3(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonAltWaningCrescent3"


class WiMoonAltWaningCrescent4(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonAltWaningCrescent4"


class WiMoonAltWaningCrescent5(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonAltWaningCrescent5"


class WiMoonAltWaningCrescent6(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonAltWaningCrescent6"


class WiMoonAltWaningGibbous1(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonAltWaningGibbous1"


class WiMoonAltWaningGibbous2(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonAltWaningGibbous2"


class WiMoonAltWaningGibbous3(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonAltWaningGibbous3"


class WiMoonAltWaningGibbous4(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonAltWaningGibbous4"


class WiMoonAltWaningGibbous5(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonAltWaningGibbous5"


class WiMoonAltWaningGibbous6(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonAltWaningGibbous6"


class WiMoonAltWaxingCrescent1(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonAltWaxingCrescent1"


class WiMoonAltWaxingCrescent2(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonAltWaxingCrescent2"


class WiMoonAltWaxingCrescent3(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonAltWaxingCrescent3"


class WiMoonAltWaxingCrescent4(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonAltWaxingCrescent4"


class WiMoonAltWaxingCrescent5(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonAltWaxingCrescent5"


class WiMoonAltWaxingCrescent6(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonAltWaxingCrescent6"


class WiMoonAltWaxingGibbous1(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonAltWaxingGibbous1"


class WiMoonAltWaxingGibbous2(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonAltWaxingGibbous2"


class WiMoonAltWaxingGibbous3(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonAltWaxingGibbous3"


class WiMoonAltWaxingGibbous4(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonAltWaxingGibbous4"


class WiMoonAltWaxingGibbous5(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonAltWaxingGibbous5"


class WiMoonAltWaxingGibbous6(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonAltWaxingGibbous6"


class WiMoonFirstQuarter(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonFirstQuarter"


class WiMoonFull(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonFull"


class WiMoonNew(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonNew"


class WiMoonThirdQuarter(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonThirdQuarter"


class WiMoonWaningCrescent1(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonWaningCrescent1"


class WiMoonWaningCrescent2(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonWaningCrescent2"


class WiMoonWaningCrescent3(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonWaningCrescent3"


class WiMoonWaningCrescent4(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonWaningCrescent4"


class WiMoonWaningCrescent5(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonWaningCrescent5"


class WiMoonWaningCrescent6(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonWaningCrescent6"


class WiMoonWaningGibbous1(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonWaningGibbous1"


class WiMoonWaningGibbous2(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonWaningGibbous2"


class WiMoonWaningGibbous3(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonWaningGibbous3"


class WiMoonWaningGibbous4(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonWaningGibbous4"


class WiMoonWaningGibbous5(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonWaningGibbous5"


class WiMoonWaningGibbous6(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonWaningGibbous6"


class WiMoonWaxing6(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonWaxing6"


class WiMoonWaxingCrescent1(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonWaxingCrescent1"


class WiMoonWaxingCrescent2(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonWaxingCrescent2"


class WiMoonWaxingCrescent3(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonWaxingCrescent3"


class WiMoonWaxingCrescent4(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonWaxingCrescent4"


class WiMoonWaxingCrescent5(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonWaxingCrescent5"


class WiMoonWaxingGibbous1(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonWaxingGibbous1"


class WiMoonWaxingGibbous2(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonWaxingGibbous2"


class WiMoonWaxingGibbous3(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonWaxingGibbous3"


class WiMoonWaxingGibbous4(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonWaxingGibbous4"


class WiMoonWaxingGibbous5(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonWaxingGibbous5"


class WiMoonWaxingGibbous6(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonWaxingGibbous6"


class WiMoonrise(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonrise"


class WiMoonset(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonset"


class WiNa(rx.Component):
    library = "react-icons/wi"
    tag = "WiNa"


class WiNightAltCloudyGusts(rx.Component):
    library = "react-icons/wi"
    tag = "WiNightAltCloudyGusts"


class WiNightAltCloudyHigh(rx.Component):
    library = "react-icons/wi"
    tag = "WiNightAltCloudyHigh"


class WiNightAltCloudyWindy(rx.Component):
    library = "react-icons/wi"
    tag = "WiNightAltCloudyWindy"


class WiNightAltCloudy(rx.Component):
    library = "react-icons/wi"
    tag = "WiNightAltCloudy"


class WiNightAltHail(rx.Component):
    library = "react-icons/wi"
    tag = "WiNightAltHail"


class WiNightAltLightning(rx.Component):
    library = "react-icons/wi"
    tag = "WiNightAltLightning"


class WiNightAltPartlyCloudy(rx.Component):
    library = "react-icons/wi"
    tag = "WiNightAltPartlyCloudy"


class WiNightAltRainMix(rx.Component):
    library = "react-icons/wi"
    tag = "WiNightAltRainMix"


class WiNightAltRainWind(rx.Component):
    library = "react-icons/wi"
    tag = "WiNightAltRainWind"


class WiNightAltRain(rx.Component):
    library = "react-icons/wi"
    tag = "WiNightAltRain"


class WiNightAltShowers(rx.Component):
    library = "react-icons/wi"
    tag = "WiNightAltShowers"


class WiNightAltSleetStorm(rx.Component):
    library = "react-icons/wi"
    tag = "WiNightAltSleetStorm"


class WiNightAltSleet(rx.Component):
    library = "react-icons/wi"
    tag = "WiNightAltSleet"


class WiNightAltSnowThunderstorm(rx.Component):
    library = "react-icons/wi"
    tag = "WiNightAltSnowThunderstorm"


class WiNightAltSnowWind(rx.Component):
    library = "react-icons/wi"
    tag = "WiNightAltSnowWind"


class WiNightAltSnow(rx.Component):
    library = "react-icons/wi"
    tag = "WiNightAltSnow"


class WiNightAltSprinkle(rx.Component):
    library = "react-icons/wi"
    tag = "WiNightAltSprinkle"


class WiNightAltStormShowers(rx.Component):
    library = "react-icons/wi"
    tag = "WiNightAltStormShowers"


class WiNightAltThunderstorm(rx.Component):
    library = "react-icons/wi"
    tag = "WiNightAltThunderstorm"


class WiNightClear(rx.Component):
    library = "react-icons/wi"
    tag = "WiNightClear"


class WiNightCloudyGusts(rx.Component):
    library = "react-icons/wi"
    tag = "WiNightCloudyGusts"


class WiNightCloudyHigh(rx.Component):
    library = "react-icons/wi"
    tag = "WiNightCloudyHigh"


class WiNightCloudyWindy(rx.Component):
    library = "react-icons/wi"
    tag = "WiNightCloudyWindy"


class WiNightCloudy(rx.Component):
    library = "react-icons/wi"
    tag = "WiNightCloudy"


class WiNightFog(rx.Component):
    library = "react-icons/wi"
    tag = "WiNightFog"


class WiNightHail(rx.Component):
    library = "react-icons/wi"
    tag = "WiNightHail"


class WiNightLightning(rx.Component):
    library = "react-icons/wi"
    tag = "WiNightLightning"


class WiNightPartlyCloudy(rx.Component):
    library = "react-icons/wi"
    tag = "WiNightPartlyCloudy"


class WiNightRainMix(rx.Component):
    library = "react-icons/wi"
    tag = "WiNightRainMix"


class WiNightRainWind(rx.Component):
    library = "react-icons/wi"
    tag = "WiNightRainWind"


class WiNightRain(rx.Component):
    library = "react-icons/wi"
    tag = "WiNightRain"


class WiNightShowers(rx.Component):
    library = "react-icons/wi"
    tag = "WiNightShowers"


class WiNightSleetStorm(rx.Component):
    library = "react-icons/wi"
    tag = "WiNightSleetStorm"


class WiNightSleet(rx.Component):
    library = "react-icons/wi"
    tag = "WiNightSleet"


class WiNightSnowThunderstorm(rx.Component):
    library = "react-icons/wi"
    tag = "WiNightSnowThunderstorm"


class WiNightSnowWind(rx.Component):
    library = "react-icons/wi"
    tag = "WiNightSnowWind"


class WiNightSnow(rx.Component):
    library = "react-icons/wi"
    tag = "WiNightSnow"


class WiNightSprinkle(rx.Component):
    library = "react-icons/wi"
    tag = "WiNightSprinkle"


class WiNightStormShowers(rx.Component):
    library = "react-icons/wi"
    tag = "WiNightStormShowers"


class WiNightThunderstorm(rx.Component):
    library = "react-icons/wi"
    tag = "WiNightThunderstorm"


class WiRainMix(rx.Component):
    library = "react-icons/wi"
    tag = "WiRainMix"


class WiRainWind(rx.Component):
    library = "react-icons/wi"
    tag = "WiRainWind"


class WiRain(rx.Component):
    library = "react-icons/wi"
    tag = "WiRain"


class WiRaindrop(rx.Component):
    library = "react-icons/wi"
    tag = "WiRaindrop"


class WiRaindrops(rx.Component):
    library = "react-icons/wi"
    tag = "WiRaindrops"


class WiRefreshAlt(rx.Component):
    library = "react-icons/wi"
    tag = "WiRefreshAlt"


class WiRefresh(rx.Component):
    library = "react-icons/wi"
    tag = "WiRefresh"


class WiSandstorm(rx.Component):
    library = "react-icons/wi"
    tag = "WiSandstorm"


class WiShowers(rx.Component):
    library = "react-icons/wi"
    tag = "WiShowers"


class WiSleet(rx.Component):
    library = "react-icons/wi"
    tag = "WiSleet"


class WiSmallCraftAdvisory(rx.Component):
    library = "react-icons/wi"
    tag = "WiSmallCraftAdvisory"


class WiSmog(rx.Component):
    library = "react-icons/wi"
    tag = "WiSmog"


class WiSmoke(rx.Component):
    library = "react-icons/wi"
    tag = "WiSmoke"


class WiSnowWind(rx.Component):
    library = "react-icons/wi"
    tag = "WiSnowWind"


class WiSnow(rx.Component):
    library = "react-icons/wi"
    tag = "WiSnow"


class WiSnowflakeCold(rx.Component):
    library = "react-icons/wi"
    tag = "WiSnowflakeCold"


class WiSolarEclipse(rx.Component):
    library = "react-icons/wi"
    tag = "WiSolarEclipse"


class WiSprinkle(rx.Component):
    library = "react-icons/wi"
    tag = "WiSprinkle"


class WiStars(rx.Component):
    library = "react-icons/wi"
    tag = "WiStars"


class WiStormShowers(rx.Component):
    library = "react-icons/wi"
    tag = "WiStormShowers"


class WiStormWarning(rx.Component):
    library = "react-icons/wi"
    tag = "WiStormWarning"


class WiStrongWind(rx.Component):
    library = "react-icons/wi"
    tag = "WiStrongWind"


class WiSunrise(rx.Component):
    library = "react-icons/wi"
    tag = "WiSunrise"


class WiSunset(rx.Component):
    library = "react-icons/wi"
    tag = "WiSunset"


class WiThermometerExterior(rx.Component):
    library = "react-icons/wi"
    tag = "WiThermometerExterior"


class WiThermometerInternal(rx.Component):
    library = "react-icons/wi"
    tag = "WiThermometerInternal"


class WiThermometer(rx.Component):
    library = "react-icons/wi"
    tag = "WiThermometer"


class WiThunderstorm(rx.Component):
    library = "react-icons/wi"
    tag = "WiThunderstorm"


class WiTime1(rx.Component):
    library = "react-icons/wi"
    tag = "WiTime1"


class WiTime10(rx.Component):
    library = "react-icons/wi"
    tag = "WiTime10"


class WiTime11(rx.Component):
    library = "react-icons/wi"
    tag = "WiTime11"


class WiTime12(rx.Component):
    library = "react-icons/wi"
    tag = "WiTime12"


class WiTime2(rx.Component):
    library = "react-icons/wi"
    tag = "WiTime2"


class WiTime3(rx.Component):
    library = "react-icons/wi"
    tag = "WiTime3"


class WiTime4(rx.Component):
    library = "react-icons/wi"
    tag = "WiTime4"


class WiTime5(rx.Component):
    library = "react-icons/wi"
    tag = "WiTime5"


class WiTime6(rx.Component):
    library = "react-icons/wi"
    tag = "WiTime6"


class WiTime7(rx.Component):
    library = "react-icons/wi"
    tag = "WiTime7"


class WiTime8(rx.Component):
    library = "react-icons/wi"
    tag = "WiTime8"


class WiTime9(rx.Component):
    library = "react-icons/wi"
    tag = "WiTime9"


class WiTornado(rx.Component):
    library = "react-icons/wi"
    tag = "WiTornado"


class WiTrain(rx.Component):
    library = "react-icons/wi"
    tag = "WiTrain"


class WiTsunami(rx.Component):
    library = "react-icons/wi"
    tag = "WiTsunami"


class WiUmbrella(rx.Component):
    library = "react-icons/wi"
    tag = "WiUmbrella"


class WiVolcano(rx.Component):
    library = "react-icons/wi"
    tag = "WiVolcano"


class WiWindBeaufort0(rx.Component):
    library = "react-icons/wi"
    tag = "WiWindBeaufort0"


class WiWindBeaufort1(rx.Component):
    library = "react-icons/wi"
    tag = "WiWindBeaufort1"


class WiWindBeaufort10(rx.Component):
    library = "react-icons/wi"
    tag = "WiWindBeaufort10"


class WiWindBeaufort11(rx.Component):
    library = "react-icons/wi"
    tag = "WiWindBeaufort11"


class WiWindBeaufort12(rx.Component):
    library = "react-icons/wi"
    tag = "WiWindBeaufort12"


class WiWindBeaufort2(rx.Component):
    library = "react-icons/wi"
    tag = "WiWindBeaufort2"


class WiWindBeaufort3(rx.Component):
    library = "react-icons/wi"
    tag = "WiWindBeaufort3"


class WiWindBeaufort4(rx.Component):
    library = "react-icons/wi"
    tag = "WiWindBeaufort4"


class WiWindBeaufort5(rx.Component):
    library = "react-icons/wi"
    tag = "WiWindBeaufort5"


class WiWindBeaufort6(rx.Component):
    library = "react-icons/wi"
    tag = "WiWindBeaufort6"


class WiWindBeaufort7(rx.Component):
    library = "react-icons/wi"
    tag = "WiWindBeaufort7"


class WiWindBeaufort8(rx.Component):
    library = "react-icons/wi"
    tag = "WiWindBeaufort8"


class WiWindBeaufort9(rx.Component):
    library = "react-icons/wi"
    tag = "WiWindBeaufort9"


class WiWindDeg(rx.Component):
    library = "react-icons/wi"
    tag = "WiWindDeg"


class WiWindy(rx.Component):
    library = "react-icons/wi"
    tag = "WiWindy"


